# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'D4matSlicerQ_Main.ui'
#
# Created: Fri Apr  2 10:16:28 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_D4matSlicerQtMain(object):
    def setupUi(self, D4matSlicerQtMain):
        D4matSlicerQtMain.setObjectName("D4matSlicerQtMain")
        D4matSlicerQtMain.resize(550, 720)
        self.centralwidget = QtGui.QWidget(D4matSlicerQtMain)
        self.centralwidget.setObjectName("centralwidget")
        self.panel1 = QtGui.QGroupBox(self.centralwidget)
        self.panel1.setGeometry(QtCore.QRect(10, 0, 530, 55))
        self.panel1.setObjectName("panel1")
        self.btMakeVirtualMat = QtGui.QPushButton(self.panel1)
        self.btMakeVirtualMat.setGeometry(QtCore.QRect(10, 20, 80, 25))
        self.btMakeVirtualMat.setAutoDefault(True)
        self.btMakeVirtualMat.setObjectName("btMakeVirtualMat")
        self.txtvmsg = QtGui.QLabel(self.panel1)
        self.txtvmsg.setGeometry(QtCore.QRect(100, 25, 421, 20))
        self.txtvmsg.setObjectName("txtvmsg")
        self.panel2 = QtGui.QGroupBox(self.centralwidget)
        self.panel2.setGeometry(QtCore.QRect(10, 55, 530, 55))
        self.panel2.setTitle("D4Matrix Files")
        self.panel2.setFlat(False)
        self.panel2.setCheckable(False)
        self.panel2.setObjectName("panel2")
        self.btOpenD4Matrix = QtGui.QPushButton(self.panel2)
        self.btOpenD4Matrix.setGeometry(QtCore.QRect(10, 20, 80, 25))
        self.btOpenD4Matrix.setAutoDefault(True)
        self.btOpenD4Matrix.setObjectName("btOpenD4Matrix")
        self.stPathToD4MatrixFiles = QtGui.QLabel(self.panel2)
        self.stPathToD4MatrixFiles.setGeometry(QtCore.QRect(100, 25, 421, 20))
        self.stPathToD4MatrixFiles.setObjectName("stPathToD4MatrixFiles")
        self.panel3 = QtGui.QGroupBox(self.centralwidget)
        self.panel3.setGeometry(QtCore.QRect(10, 110, 530, 131))
        self.panel3.setObjectName("panel3")
        self.label_2 = QtGui.QLabel(self.panel3)
        self.label_2.setGeometry(QtCore.QRect(80, 20, 60, 20))
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.label_3 = QtGui.QLabel(self.panel3)
        self.label_3.setGeometry(QtCore.QRect(210, 20, 60, 20))
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.label_4 = QtGui.QLabel(self.panel3)
        self.label_4.setGeometry(QtCore.QRect(300, 20, 60, 20))
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName("label_4")
        self.v1txt = QtGui.QLabel(self.panel3)
        self.v1txt.setGeometry(QtCore.QRect(10, 40, 30, 20))
        self.v1txt.setObjectName("v1txt")
        self.txt1 = QtGui.QLabel(self.panel3)
        self.txt1.setGeometry(QtCore.QRect(40, 40, 60, 20))
        self.txt1.setAlignment(QtCore.Qt.AlignCenter)
        self.txt1.setObjectName("txt1")
        self.label_6 = QtGui.QLabel(self.panel3)
        self.label_6.setGeometry(QtCore.QRect(100, 40, 30, 20))
        self.label_6.setAlignment(QtCore.Qt.AlignCenter)
        self.label_6.setObjectName("label_6")
        self.txt2 = QtGui.QLabel(self.panel3)
        self.txt2.setGeometry(QtCore.QRect(130, 40, 60, 20))
        self.txt2.setAlignment(QtCore.Qt.AlignCenter)
        self.txt2.setObjectName("txt2")
        self.txt3 = QtGui.QLabel(self.panel3)
        self.txt3.setGeometry(QtCore.QRect(210, 40, 60, 20))
        self.txt3.setAlignment(QtCore.Qt.AlignCenter)
        self.txt3.setObjectName("txt3")
        self.label_7 = QtGui.QLabel(self.panel3)
        self.label_7.setGeometry(QtCore.QRect(100, 60, 30, 20))
        self.label_7.setAlignment(QtCore.Qt.AlignCenter)
        self.label_7.setObjectName("label_7")
        self.txt5 = QtGui.QLabel(self.panel3)
        self.txt5.setGeometry(QtCore.QRect(130, 60, 60, 20))
        self.txt5.setAlignment(QtCore.Qt.AlignCenter)
        self.txt5.setObjectName("txt5")
        self.txt4 = QtGui.QLabel(self.panel3)
        self.txt4.setGeometry(QtCore.QRect(40, 60, 60, 20))
        self.txt4.setAlignment(QtCore.Qt.AlignCenter)
        self.txt4.setObjectName("txt4")
        self.v2txt = QtGui.QLabel(self.panel3)
        self.v2txt.setGeometry(QtCore.QRect(10, 60, 30, 20))
        self.v2txt.setObjectName("v2txt")
        self.txt6 = QtGui.QLabel(self.panel3)
        self.txt6.setGeometry(QtCore.QRect(210, 60, 60, 20))
        self.txt6.setAlignment(QtCore.Qt.AlignCenter)
        self.txt6.setObjectName("txt6")
        self.label_8 = QtGui.QLabel(self.panel3)
        self.label_8.setGeometry(QtCore.QRect(100, 80, 30, 20))
        self.label_8.setAlignment(QtCore.Qt.AlignCenter)
        self.label_8.setObjectName("label_8")
        self.txt8 = QtGui.QLabel(self.panel3)
        self.txt8.setGeometry(QtCore.QRect(130, 80, 60, 20))
        self.txt8.setAlignment(QtCore.Qt.AlignCenter)
        self.txt8.setObjectName("txt8")
        self.txt7 = QtGui.QLabel(self.panel3)
        self.txt7.setGeometry(QtCore.QRect(40, 80, 60, 20))
        self.txt7.setAlignment(QtCore.Qt.AlignCenter)
        self.txt7.setObjectName("txt7")
        self.v3txt = QtGui.QLabel(self.panel3)
        self.v3txt.setGeometry(QtCore.QRect(10, 80, 30, 20))
        self.v3txt.setObjectName("v3txt")
        self.txt9 = QtGui.QLabel(self.panel3)
        self.txt9.setGeometry(QtCore.QRect(210, 80, 60, 20))
        self.txt9.setAlignment(QtCore.Qt.AlignCenter)
        self.txt9.setObjectName("txt9")
        self.label_9 = QtGui.QLabel(self.panel3)
        self.label_9.setGeometry(QtCore.QRect(100, 100, 30, 20))
        self.label_9.setAlignment(QtCore.Qt.AlignCenter)
        self.label_9.setObjectName("label_9")
        self.txt11 = QtGui.QLabel(self.panel3)
        self.txt11.setGeometry(QtCore.QRect(130, 100, 60, 20))
        self.txt11.setAlignment(QtCore.Qt.AlignCenter)
        self.txt11.setObjectName("txt11")
        self.txt10 = QtGui.QLabel(self.panel3)
        self.txt10.setGeometry(QtCore.QRect(40, 100, 60, 20))
        self.txt10.setAlignment(QtCore.Qt.AlignCenter)
        self.txt10.setObjectName("txt10")
        self.v4txt = QtGui.QLabel(self.panel3)
        self.v4txt.setGeometry(QtCore.QRect(10, 100, 30, 20))
        self.v4txt.setObjectName("v4txt")
        self.txt12 = QtGui.QLabel(self.panel3)
        self.txt12.setGeometry(QtCore.QRect(210, 100, 60, 20))
        self.txt12.setAlignment(QtCore.Qt.AlignCenter)
        self.txt12.setObjectName("txt12")
        self.v1title = QtGui.QLineEdit(self.panel3)
        self.v1title.setGeometry(QtCore.QRect(280, 40, 101, 20))
        self.v1title.setObjectName("v1title")
        self.v2title = QtGui.QLineEdit(self.panel3)
        self.v2title.setGeometry(QtCore.QRect(280, 60, 101, 20))
        self.v2title.setObjectName("v2title")
        self.v3title = QtGui.QLineEdit(self.panel3)
        self.v3title.setGeometry(QtCore.QRect(280, 80, 101, 20))
        self.v3title.setObjectName("v3title")
        self.v4title = QtGui.QLineEdit(self.panel3)
        self.v4title.setGeometry(QtCore.QRect(280, 100, 101, 20))
        self.v4title.setObjectName("v4title")
        self.btCloseMatrix = QtGui.QPushButton(self.panel3)
        self.btCloseMatrix.setGeometry(QtCore.QRect(464, 25, 60, 25))
        self.btCloseMatrix.setAutoDefault(True)
        self.btCloseMatrix.setObjectName("btCloseMatrix")
        self.panel31 = QtGui.QGroupBox(self.panel3)
        self.panel31.setGeometry(QtCore.QRect(460, 60, 71, 66))
        self.panel31.setFlat(False)
        self.panel31.setObjectName("panel31")
        self.btClearColumn = QtGui.QPushButton(self.panel31)
        self.btClearColumn.setGeometry(QtCore.QRect(5, 20, 60, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btClearColumn.setFont(font)
        self.btClearColumn.setAutoDefault(True)
        self.btClearColumn.setObjectName("btClearColumn")
        self.btSaveTitles = QtGui.QPushButton(self.panel31)
        self.btSaveTitles.setGeometry(QtCore.QRect(5, 40, 60, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btSaveTitles.setFont(font)
        self.btSaveTitles.setAutoDefault(True)
        self.btSaveTitles.setObjectName("btSaveTitles")
        self.v1unit = QtGui.QLineEdit(self.panel3)
        self.v1unit.setGeometry(QtCore.QRect(390, 40, 61, 20))
        self.v1unit.setObjectName("v1unit")
        self.v2unit = QtGui.QLineEdit(self.panel3)
        self.v2unit.setGeometry(QtCore.QRect(390, 60, 61, 20))
        self.v2unit.setObjectName("v2unit")
        self.v3unit = QtGui.QLineEdit(self.panel3)
        self.v3unit.setGeometry(QtCore.QRect(390, 80, 61, 20))
        self.v3unit.setObjectName("v3unit")
        self.v4unit = QtGui.QLineEdit(self.panel3)
        self.v4unit.setGeometry(QtCore.QRect(390, 100, 61, 20))
        self.v4unit.setObjectName("v4unit")
        self.label_17 = QtGui.QLabel(self.panel3)
        self.label_17.setGeometry(QtCore.QRect(390, 20, 60, 20))
        self.label_17.setAlignment(QtCore.Qt.AlignCenter)
        self.label_17.setObjectName("label_17")
        self.panel4 = QtGui.QGroupBox(self.centralwidget)
        self.panel4.setGeometry(QtCore.QRect(10, 240, 530, 160))
        self.panel4.setObjectName("panel4")
        self.btAddSingleFile = QtGui.QPushButton(self.panel4)
        self.btAddSingleFile.setGeometry(QtCore.QRect(10, 130, 100, 25))
        self.btAddSingleFile.setAutoDefault(True)
        self.btAddSingleFile.setObjectName("btAddSingleFile")
        self.btAddFilesInDir = QtGui.QPushButton(self.panel4)
        self.btAddFilesInDir.setGeometry(QtCore.QRect(140, 130, 150, 25))
        self.btAddFilesInDir.setAutoDefault(True)
        self.btAddFilesInDir.setObjectName("btAddFilesInDir")
        self.btRemoveFile = QtGui.QPushButton(self.panel4)
        self.btRemoveFile.setGeometry(QtCore.QRect(420, 130, 100, 25))
        self.btRemoveFile.setAutoDefault(True)
        self.btRemoveFile.setObjectName("btRemoveFile")
        self.lbFileList = QtGui.QTreeWidget(self.panel4)
        self.lbFileList.setGeometry(QtCore.QRect(10, 30, 510, 100))
        self.lbFileList.setObjectName("lbFileList")
        self.lbFileList.headerItem().setText(0, "1")
        self.lbFileList.header().setVisible(False)
        self.panel5 = QtGui.QGroupBox(self.centralwidget)
        self.panel5.setGeometry(QtCore.QRect(10, 400, 530, 190))
        self.panel5.setStyleSheet("")
        self.panel5.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.panel5.setObjectName("panel5")
        self.label_5 = QtGui.QLabel(self.panel5)
        self.label_5.setGeometry(QtCore.QRect(80, 30, 70, 20))
        self.label_5.setAlignment(QtCore.Qt.AlignCenter)
        self.label_5.setObjectName("label_5")
        self.label_10 = QtGui.QLabel(self.panel5)
        self.label_10.setGeometry(QtCore.QRect(230, 30, 70, 20))
        self.label_10.setAlignment(QtCore.Qt.AlignCenter)
        self.label_10.setObjectName("label_10")
        self.v1txt_2 = QtGui.QLabel(self.panel5)
        self.v1txt_2.setGeometry(QtCore.QRect(10, 55, 30, 20))
        self.v1txt_2.setObjectName("v1txt_2")
        self.v2txt_2 = QtGui.QLabel(self.panel5)
        self.v2txt_2.setGeometry(QtCore.QRect(10, 80, 30, 20))
        self.v2txt_2.setObjectName("v2txt_2")
        self.v4txt_2 = QtGui.QLabel(self.panel5)
        self.v4txt_2.setGeometry(QtCore.QRect(10, 130, 30, 20))
        self.v4txt_2.setObjectName("v4txt_2")
        self.v3txt_2 = QtGui.QLabel(self.panel5)
        self.v3txt_2.setGeometry(QtCore.QRect(10, 105, 30, 20))
        self.v3txt_2.setObjectName("v3txt_2")
        self.stxt1 = QtGui.QLineEdit(self.panel5)
        self.stxt1.setGeometry(QtCore.QRect(50, 55, 60, 20))
        self.stxt1.setObjectName("stxt1")
        self.label_11 = QtGui.QLabel(self.panel5)
        self.label_11.setGeometry(QtCore.QRect(110, 80, 30, 20))
        self.label_11.setAlignment(QtCore.Qt.AlignCenter)
        self.label_11.setObjectName("label_11")
        self.label_12 = QtGui.QLabel(self.panel5)
        self.label_12.setGeometry(QtCore.QRect(110, 55, 30, 20))
        self.label_12.setAlignment(QtCore.Qt.AlignCenter)
        self.label_12.setObjectName("label_12")
        self.label_13 = QtGui.QLabel(self.panel5)
        self.label_13.setGeometry(QtCore.QRect(110, 105, 30, 20))
        self.label_13.setAlignment(QtCore.Qt.AlignCenter)
        self.label_13.setObjectName("label_13")
        self.label_14 = QtGui.QLabel(self.panel5)
        self.label_14.setGeometry(QtCore.QRect(110, 130, 30, 20))
        self.label_14.setAlignment(QtCore.Qt.AlignCenter)
        self.label_14.setObjectName("label_14")
        self.stxt2 = QtGui.QLineEdit(self.panel5)
        self.stxt2.setGeometry(QtCore.QRect(140, 55, 60, 20))
        self.stxt2.setObjectName("stxt2")
        self.btAutoFillAx1 = QtGui.QPushButton(self.panel5)
        self.btAutoFillAx1.setGeometry(QtCore.QRect(210, 55, 32, 24))
        self.btAutoFillAx1.setAutoDefault(True)
        self.btAutoFillAx1.setObjectName("btAutoFillAx1")
        self.txtFold1 = QtGui.QLineEdit(self.panel5)
        self.txtFold1.setGeometry(QtCore.QRect(250, 55, 40, 20))
        self.txtFold1.setObjectName("txtFold1")
        self.v1cb = QtGui.QComboBox(self.panel5)
        self.v1cb.setGeometry(QtCore.QRect(370, 55, 80, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setWeight(50)
        font.setItalic(False)
        font.setBold(False)
        self.v1cb.setFont(font)
        self.v1cb.setEditable(False)
        self.v1cb.setObjectName("v1cb")
        self.v1cb.addItem("")
        self.v1cb.addItem("")
        self.v1cb.addItem("")
        self.v1cb.addItem("")
        self.stxt3 = QtGui.QLineEdit(self.panel5)
        self.stxt3.setEnabled(False)
        self.stxt3.setGeometry(QtCore.QRect(460, 55, 60, 20))
        self.stxt3.setObjectName("stxt3")
        self.btAutoFillAx2 = QtGui.QPushButton(self.panel5)
        self.btAutoFillAx2.setGeometry(QtCore.QRect(210, 80, 32, 24))
        self.btAutoFillAx2.setAutoDefault(True)
        self.btAutoFillAx2.setObjectName("btAutoFillAx2")
        self.stxt5 = QtGui.QLineEdit(self.panel5)
        self.stxt5.setGeometry(QtCore.QRect(140, 80, 60, 20))
        self.stxt5.setObjectName("stxt5")
        self.v2cb = QtGui.QComboBox(self.panel5)
        self.v2cb.setGeometry(QtCore.QRect(370, 80, 80, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.v2cb.setFont(font)
        self.v2cb.setEditable(False)
        self.v2cb.setObjectName("v2cb")
        self.v2cb.addItem("")
        self.v2cb.addItem("")
        self.v2cb.addItem("")
        self.v2cb.addItem("")
        self.txtFold2 = QtGui.QLineEdit(self.panel5)
        self.txtFold2.setGeometry(QtCore.QRect(250, 80, 40, 20))
        self.txtFold2.setObjectName("txtFold2")
        self.stxt6 = QtGui.QLineEdit(self.panel5)
        self.stxt6.setEnabled(False)
        self.stxt6.setGeometry(QtCore.QRect(460, 80, 60, 20))
        self.stxt6.setObjectName("stxt6")
        self.stxt4 = QtGui.QLineEdit(self.panel5)
        self.stxt4.setGeometry(QtCore.QRect(50, 80, 60, 20))
        self.stxt4.setObjectName("stxt4")
        self.btAutoFillAx3 = QtGui.QPushButton(self.panel5)
        self.btAutoFillAx3.setGeometry(QtCore.QRect(210, 105, 32, 24))
        self.btAutoFillAx3.setAutoDefault(True)
        self.btAutoFillAx3.setObjectName("btAutoFillAx3")
        self.stxt8 = QtGui.QLineEdit(self.panel5)
        self.stxt8.setGeometry(QtCore.QRect(140, 105, 60, 20))
        self.stxt8.setObjectName("stxt8")
        self.v3cb = QtGui.QComboBox(self.panel5)
        self.v3cb.setGeometry(QtCore.QRect(370, 105, 80, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.v3cb.setFont(font)
        self.v3cb.setEditable(False)
        self.v3cb.setObjectName("v3cb")
        self.v3cb.addItem("")
        self.v3cb.addItem("")
        self.v3cb.addItem("")
        self.v3cb.addItem("")
        self.txtFold3 = QtGui.QLineEdit(self.panel5)
        self.txtFold3.setGeometry(QtCore.QRect(250, 105, 40, 20))
        self.txtFold3.setObjectName("txtFold3")
        self.stxt9 = QtGui.QLineEdit(self.panel5)
        self.stxt9.setEnabled(False)
        self.stxt9.setGeometry(QtCore.QRect(460, 105, 60, 20))
        self.stxt9.setObjectName("stxt9")
        self.stxt7 = QtGui.QLineEdit(self.panel5)
        self.stxt7.setGeometry(QtCore.QRect(50, 105, 60, 20))
        self.stxt7.setObjectName("stxt7")
        self.stxt10 = QtGui.QLineEdit(self.panel5)
        self.stxt10.setGeometry(QtCore.QRect(50, 130, 60, 20))
        self.stxt10.setObjectName("stxt10")
        self.stxt11 = QtGui.QLineEdit(self.panel5)
        self.stxt11.setGeometry(QtCore.QRect(140, 130, 60, 20))
        self.stxt11.setObjectName("stxt11")
        self.btAutoFillAx4 = QtGui.QPushButton(self.panel5)
        self.btAutoFillAx4.setGeometry(QtCore.QRect(210, 130, 32, 24))
        self.btAutoFillAx4.setAutoDefault(True)
        self.btAutoFillAx4.setObjectName("btAutoFillAx4")
        self.stxt12 = QtGui.QLineEdit(self.panel5)
        self.stxt12.setEnabled(False)
        self.stxt12.setGeometry(QtCore.QRect(460, 130, 60, 20))
        self.stxt12.setObjectName("stxt12")
        self.v4cb = QtGui.QComboBox(self.panel5)
        self.v4cb.setGeometry(QtCore.QRect(370, 130, 80, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.v4cb.setFont(font)
        self.v4cb.setEditable(False)
        self.v4cb.setObjectName("v4cb")
        self.v4cb.addItem("")
        self.v4cb.addItem("")
        self.v4cb.addItem("")
        self.v4cb.addItem("")
        self.txtFold4 = QtGui.QLineEdit(self.panel5)
        self.txtFold4.setGeometry(QtCore.QRect(250, 130, 40, 20))
        self.txtFold4.setObjectName("txtFold4")
        self.btBack = QtGui.QToolButton(self.panel5)
        self.btBack.setGeometry(QtCore.QRect(250, 160, 25, 25))
        self.btBack.setArrowType(QtCore.Qt.LeftArrow)
        self.btBack.setObjectName("btBack")
        self.btForward = QtGui.QToolButton(self.panel5)
        self.btForward.setGeometry(QtCore.QRect(290, 160, 25, 25))
        self.btForward.setArrowType(QtCore.Qt.RightArrow)
        self.btForward.setObjectName("btForward")
        self.btSlice = QtGui.QPushButton(self.panel5)
        self.btSlice.setGeometry(QtCore.QRect(330, 160, 81, 27))
        self.btSlice.setAutoDefault(True)
        self.btSlice.setObjectName("btSlice")
        self.btSlice3D = QtGui.QPushButton(self.panel5)
        self.btSlice3D.setGeometry(QtCore.QRect(440, 160, 81, 27))
        self.btSlice3D.setObjectName("btSlice3D")
        self.btAutoFill = QtGui.QPushButton(self.panel5)
        self.btAutoFill.setGeometry(QtCore.QRect(140, 25, 51, 27))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btAutoFill.setFont(font)
        self.btAutoFill.setAutoDefault(True)
        self.btAutoFill.setObjectName("btAutoFill")
        self.cbDiagFoldType = QtGui.QComboBox(self.panel5)
        self.cbDiagFoldType.setGeometry(QtCore.QRect(300, 25, 71, 27))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.cbDiagFoldType.setFont(font)
        self.cbDiagFoldType.setObjectName("cbDiagFoldType")
        self.cbDiagFoldType.addItem("")
        self.cbDiagFoldType.addItem("")
        self.cbDiagFoldType.addItem("")
        self.cbDiagFoldType.addItem("")
        self.ckbUseAx1Fold = QtGui.QCheckBox(self.panel5)
        self.ckbUseAx1Fold.setGeometry(QtCore.QRect(300, 55, 71, 22))
        self.ckbUseAx1Fold.setObjectName("ckbUseAx1Fold")
        self.ckbUseAx2Fold = QtGui.QCheckBox(self.panel5)
        self.ckbUseAx2Fold.setGeometry(QtCore.QRect(300, 80, 71, 22))
        self.ckbUseAx2Fold.setObjectName("ckbUseAx2Fold")
        self.ckbUseAx3Fold = QtGui.QCheckBox(self.panel5)
        self.ckbUseAx3Fold.setGeometry(QtCore.QRect(300, 105, 71, 22))
        self.ckbUseAx3Fold.setObjectName("ckbUseAx3Fold")
        self.ckbUseAx4Fold = QtGui.QCheckBox(self.panel5)
        self.ckbUseAx4Fold.setGeometry(QtCore.QRect(300, 130, 71, 22))
        self.ckbUseAx4Fold.setObjectName("ckbUseAx4Fold")
        self.label = QtGui.QLabel(self.panel5)
        self.label.setGeometry(QtCore.QRect(380, 30, 68, 17))
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.label_16 = QtGui.QLabel(self.panel5)
        self.label_16.setGeometry(QtCore.QRect(460, 30, 61, 17))
        self.label_16.setAlignment(QtCore.Qt.AlignCenter)
        self.label_16.setObjectName("label_16")
        self.panel6 = QtGui.QGroupBox(self.centralwidget)
        self.panel6.setGeometry(QtCore.QRect(10, 590, 530, 60))
        self.panel6.setObjectName("panel6")
        self.btDumpToText = QtGui.QPushButton(self.panel6)
        self.btDumpToText.setGeometry(QtCore.QRect(20, 25, 121, 27))
        self.btDumpToText.setObjectName("btDumpToText")
        self.btDumpToBin = QtGui.QPushButton(self.panel6)
        self.btDumpToBin.setGeometry(QtCore.QRect(150, 25, 121, 27))
        self.btDumpToBin.setObjectName("btDumpToBin")
        self.btOut3DText = QtGui.QPushButton(self.panel6)
        self.btOut3DText.setGeometry(QtCore.QRect(330, 25, 121, 27))
        self.btOut3DText.setObjectName("btOut3DText")
        self.label_15 = QtGui.QLabel(self.centralwidget)
        self.label_15.setGeometry(QtCore.QRect(10, 650, 68, 17))
        self.label_15.setObjectName("label_15")
        self.txtStatus = QtGui.QLabel(self.centralwidget)
        self.txtStatus.setGeometry(QtCore.QRect(90, 650, 421, 17))
        self.txtStatus.setObjectName("txtStatus")
        D4matSlicerQtMain.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(D4matSlicerQtMain)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 550, 28))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        D4matSlicerQtMain.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(D4matSlicerQtMain)
        self.statusbar.setObjectName("statusbar")
        D4matSlicerQtMain.setStatusBar(self.statusbar)
        self.actionMake_New_Matrix = QtGui.QAction(D4matSlicerQtMain)
        self.actionMake_New_Matrix.setObjectName("actionMake_New_Matrix")
        self.actionOpen_Matrix = QtGui.QAction(D4matSlicerQtMain)
        self.actionOpen_Matrix.setObjectName("actionOpen_Matrix")
        self.actionRebin_Matrix = QtGui.QAction(D4matSlicerQtMain)
        self.actionRebin_Matrix.setObjectName("actionRebin_Matrix")
        self.actionSave_as_Text = QtGui.QAction(D4matSlicerQtMain)
        self.actionSave_as_Text.setObjectName("actionSave_as_Text")
        self.actionExit = QtGui.QAction(D4matSlicerQtMain)
        self.actionExit.setObjectName("actionExit")
        self.menuFile.addAction(self.actionMake_New_Matrix)
        self.menuFile.addAction(self.actionOpen_Matrix)
        self.menuFile.addAction(self.actionRebin_Matrix)
        self.menuFile.addAction(self.actionSave_as_Text)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menubar.addAction(self.menuFile.menuAction())

        self.retranslateUi(D4matSlicerQtMain)
        self.v1cb.setCurrentIndex(3)
        self.v2cb.setCurrentIndex(3)
        self.v3cb.setCurrentIndex(3)
        self.v4cb.setCurrentIndex(3)
        QtCore.QMetaObject.connectSlotsByName(D4matSlicerQtMain)
        D4matSlicerQtMain.setTabOrder(self.btMakeVirtualMat, self.btOpenD4Matrix)
        D4matSlicerQtMain.setTabOrder(self.btOpenD4Matrix, self.v1title)
        D4matSlicerQtMain.setTabOrder(self.v1title, self.v1unit)
        D4matSlicerQtMain.setTabOrder(self.v1unit, self.v2title)
        D4matSlicerQtMain.setTabOrder(self.v2title, self.v2unit)
        D4matSlicerQtMain.setTabOrder(self.v2unit, self.v3title)
        D4matSlicerQtMain.setTabOrder(self.v3title, self.v3unit)
        D4matSlicerQtMain.setTabOrder(self.v3unit, self.v4title)
        D4matSlicerQtMain.setTabOrder(self.v4title, self.v4unit)
        D4matSlicerQtMain.setTabOrder(self.v4unit, self.btCloseMatrix)
        D4matSlicerQtMain.setTabOrder(self.btCloseMatrix, self.btClearColumn)
        D4matSlicerQtMain.setTabOrder(self.btClearColumn, self.btSaveTitles)
        D4matSlicerQtMain.setTabOrder(self.btSaveTitles, self.lbFileList)
        D4matSlicerQtMain.setTabOrder(self.lbFileList, self.btAddSingleFile)
        D4matSlicerQtMain.setTabOrder(self.btAddSingleFile, self.btAddFilesInDir)
        D4matSlicerQtMain.setTabOrder(self.btAddFilesInDir, self.btRemoveFile)
        D4matSlicerQtMain.setTabOrder(self.btRemoveFile, self.btAutoFill)
        D4matSlicerQtMain.setTabOrder(self.btAutoFill, self.cbDiagFoldType)
        D4matSlicerQtMain.setTabOrder(self.cbDiagFoldType, self.stxt1)
        D4matSlicerQtMain.setTabOrder(self.stxt1, self.stxt2)
        D4matSlicerQtMain.setTabOrder(self.stxt2, self.btAutoFillAx1)
        D4matSlicerQtMain.setTabOrder(self.btAutoFillAx1, self.txtFold1)
        D4matSlicerQtMain.setTabOrder(self.txtFold1, self.ckbUseAx1Fold)
        D4matSlicerQtMain.setTabOrder(self.ckbUseAx1Fold, self.v1cb)
        D4matSlicerQtMain.setTabOrder(self.v1cb, self.stxt3)
        D4matSlicerQtMain.setTabOrder(self.stxt3, self.stxt4)
        D4matSlicerQtMain.setTabOrder(self.stxt4, self.stxt5)
        D4matSlicerQtMain.setTabOrder(self.stxt5, self.btAutoFillAx2)
        D4matSlicerQtMain.setTabOrder(self.btAutoFillAx2, self.txtFold2)
        D4matSlicerQtMain.setTabOrder(self.txtFold2, self.ckbUseAx2Fold)
        D4matSlicerQtMain.setTabOrder(self.ckbUseAx2Fold, self.v2cb)
        D4matSlicerQtMain.setTabOrder(self.v2cb, self.stxt6)
        D4matSlicerQtMain.setTabOrder(self.stxt6, self.stxt7)
        D4matSlicerQtMain.setTabOrder(self.stxt7, self.stxt8)
        D4matSlicerQtMain.setTabOrder(self.stxt8, self.btAutoFillAx3)
        D4matSlicerQtMain.setTabOrder(self.btAutoFillAx3, self.txtFold3)
        D4matSlicerQtMain.setTabOrder(self.txtFold3, self.ckbUseAx3Fold)
        D4matSlicerQtMain.setTabOrder(self.ckbUseAx3Fold, self.v3cb)
        D4matSlicerQtMain.setTabOrder(self.v3cb, self.stxt9)
        D4matSlicerQtMain.setTabOrder(self.stxt9, self.stxt10)
        D4matSlicerQtMain.setTabOrder(self.stxt10, self.stxt11)
        D4matSlicerQtMain.setTabOrder(self.stxt11, self.btAutoFillAx4)
        D4matSlicerQtMain.setTabOrder(self.btAutoFillAx4, self.txtFold4)
        D4matSlicerQtMain.setTabOrder(self.txtFold4, self.ckbUseAx4Fold)
        D4matSlicerQtMain.setTabOrder(self.ckbUseAx4Fold, self.v4cb)
        D4matSlicerQtMain.setTabOrder(self.v4cb, self.stxt12)
        D4matSlicerQtMain.setTabOrder(self.stxt12, self.btBack)
        D4matSlicerQtMain.setTabOrder(self.btBack, self.btForward)
        D4matSlicerQtMain.setTabOrder(self.btForward, self.btSlice)
        D4matSlicerQtMain.setTabOrder(self.btSlice, self.btSlice3D)
        D4matSlicerQtMain.setTabOrder(self.btSlice3D, self.btDumpToText)
        D4matSlicerQtMain.setTabOrder(self.btDumpToText, self.btDumpToBin)
        D4matSlicerQtMain.setTabOrder(self.btDumpToBin, self.btOut3DText)

    def retranslateUi(self, D4matSlicerQtMain):
        D4matSlicerQtMain.setWindowTitle(QtGui.QApplication.translate("D4matSlicerQtMain", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.panel1.setTitle(QtGui.QApplication.translate("D4matSlicerQtMain", "Make Virtual or New D4Matrix", None, QtGui.QApplication.UnicodeUTF8))
        self.btMakeVirtualMat.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Make", None, QtGui.QApplication.UnicodeUTF8))
        self.txtvmsg.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "No Info", None, QtGui.QApplication.UnicodeUTF8))
        self.btOpenD4Matrix.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Open", None, QtGui.QApplication.UnicodeUTF8))
        self.stPathToD4MatrixFiles.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Path to D4Matrix files", None, QtGui.QApplication.UnicodeUTF8))
        self.panel3.setTitle(QtGui.QApplication.translate("D4matSlicerQtMain", "D4Matrix Info", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Step", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Label", None, QtGui.QApplication.UnicodeUTF8))
        self.v1txt.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Ax1:", None, QtGui.QApplication.UnicodeUTF8))
        self.txt1.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "-1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.txt2.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txt3.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.txt5.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txt4.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "-1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.v2txt.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Ax2:", None, QtGui.QApplication.UnicodeUTF8))
        self.txt6.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.txt8.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txt7.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "-1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.v3txt.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Ax3:", None, QtGui.QApplication.UnicodeUTF8))
        self.txt9.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.txt11.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txt10.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "-1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.v4txt.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Ax4:", None, QtGui.QApplication.UnicodeUTF8))
        self.txt12.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.btCloseMatrix.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Close", None, QtGui.QApplication.UnicodeUTF8))
        self.panel31.setTitle(QtGui.QApplication.translate("D4matSlicerQtMain", "Label", None, QtGui.QApplication.UnicodeUTF8))
        self.btClearColumn.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Clear", None, QtGui.QApplication.UnicodeUTF8))
        self.btSaveTitles.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.label_17.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Unit", None, QtGui.QApplication.UnicodeUTF8))
        self.panel4.setTitle(QtGui.QApplication.translate("D4matSlicerQtMain", "File Components", None, QtGui.QApplication.UnicodeUTF8))
        self.btAddSingleFile.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Add File", None, QtGui.QApplication.UnicodeUTF8))
        self.btAddFilesInDir.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Add Files in folder", None, QtGui.QApplication.UnicodeUTF8))
        self.btRemoveFile.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Remove File", None, QtGui.QApplication.UnicodeUTF8))
        self.panel5.setTitle(QtGui.QApplication.translate("D4matSlicerQtMain", "Slice", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Folding", None, QtGui.QApplication.UnicodeUTF8))
        self.v1txt_2.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Ax1:", None, QtGui.QApplication.UnicodeUTF8))
        self.v2txt_2.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Ax2:", None, QtGui.QApplication.UnicodeUTF8))
        self.v4txt_2.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Ax4:", None, QtGui.QApplication.UnicodeUTF8))
        self.v3txt_2.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Ax3:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_13.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_14.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFillAx1.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.v1cb.setItemText(0, QtGui.QApplication.translate("D4matSlicerQtMain", "X-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v1cb.setItemText(1, QtGui.QApplication.translate("D4matSlicerQtMain", "Y-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v1cb.setItemText(2, QtGui.QApplication.translate("D4matSlicerQtMain", "Z-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v1cb.setItemText(3, QtGui.QApplication.translate("D4matSlicerQtMain", "Thick", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFillAx2.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.v2cb.setItemText(0, QtGui.QApplication.translate("D4matSlicerQtMain", "X-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v2cb.setItemText(1, QtGui.QApplication.translate("D4matSlicerQtMain", "Y-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v2cb.setItemText(2, QtGui.QApplication.translate("D4matSlicerQtMain", "Z-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v2cb.setItemText(3, QtGui.QApplication.translate("D4matSlicerQtMain", "Thick", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFillAx3.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.v3cb.setItemText(0, QtGui.QApplication.translate("D4matSlicerQtMain", "X-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v3cb.setItemText(1, QtGui.QApplication.translate("D4matSlicerQtMain", "Y-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v3cb.setItemText(2, QtGui.QApplication.translate("D4matSlicerQtMain", "Z-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v3cb.setItemText(3, QtGui.QApplication.translate("D4matSlicerQtMain", "Thick", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFillAx4.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.v4cb.setItemText(0, QtGui.QApplication.translate("D4matSlicerQtMain", "X-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v4cb.setItemText(1, QtGui.QApplication.translate("D4matSlicerQtMain", "Y-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v4cb.setItemText(2, QtGui.QApplication.translate("D4matSlicerQtMain", "Z-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v4cb.setItemText(3, QtGui.QApplication.translate("D4matSlicerQtMain", "Thick", None, QtGui.QApplication.UnicodeUTF8))
        self.btBack.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "...", None, QtGui.QApplication.UnicodeUTF8))
        self.btForward.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "...", None, QtGui.QApplication.UnicodeUTF8))
        self.btSlice.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Slice2D", None, QtGui.QApplication.UnicodeUTF8))
        self.btSlice3D.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Slice3D", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFill.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Auto", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDiagFoldType.setItemText(0, QtGui.QApplication.translate("D4matSlicerQtMain", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDiagFoldType.setItemText(1, QtGui.QApplication.translate("D4matSlicerQtMain", "X > Y", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDiagFoldType.setItemText(2, QtGui.QApplication.translate("D4matSlicerQtMain", "X > -Y", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDiagFoldType.setItemText(3, QtGui.QApplication.translate("D4matSlicerQtMain", "Both", None, QtGui.QApplication.UnicodeUTF8))
        self.ckbUseAx1Fold.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "used", None, QtGui.QApplication.UnicodeUTF8))
        self.ckbUseAx2Fold.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "used", None, QtGui.QApplication.UnicodeUTF8))
        self.ckbUseAx3Fold.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "used", None, QtGui.QApplication.UnicodeUTF8))
        self.ckbUseAx4Fold.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "used", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Plot Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.label_16.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Step", None, QtGui.QApplication.UnicodeUTF8))
        self.panel6.setTitle(QtGui.QApplication.translate("D4matSlicerQtMain", "Output To File", None, QtGui.QApplication.UnicodeUTF8))
        self.btDumpToText.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Dump To Text", None, QtGui.QApplication.UnicodeUTF8))
        self.btDumpToBin.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Dump To Binary", None, QtGui.QApplication.UnicodeUTF8))
        self.btOut3DText.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Out3D as Text", None, QtGui.QApplication.UnicodeUTF8))
        self.label_15.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "STATUS :", None, QtGui.QApplication.UnicodeUTF8))
        self.txtStatus.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.menuFile.setTitle(QtGui.QApplication.translate("D4matSlicerQtMain", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMake_New_Matrix.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Make New Matrix ...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionOpen_Matrix.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Open Matrix ...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionRebin_Matrix.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Rebin Matrix ...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_as_Text.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Save as Text ...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionExit.setText(QtGui.QApplication.translate("D4matSlicerQtMain", "Exit", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'D4matSlicerQ_Sub.ui'
#
# Created: Fri Apr  2 10:16:28 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_D4matSlicerQtSub(object):
    def setupUi(self, D4matSlicerQtSub):
        D4matSlicerQtSub.setObjectName("D4matSlicerQtSub")
        D4matSlicerQtSub.resize(550, 709)
        self.centralwidget = QtGui.QWidget(D4matSlicerQtSub)
        self.centralwidget.setObjectName("centralwidget")
        self.ParamFilePanel = QtGui.QGroupBox(self.centralwidget)
        self.ParamFilePanel.setGeometry(QtCore.QRect(400, 0, 140, 51))
        self.ParamFilePanel.setObjectName("ParamFilePanel")
        self.btLoadParams = QtGui.QPushButton(self.ParamFilePanel)
        self.btLoadParams.setGeometry(QtCore.QRect(10, 20, 55, 25))
        self.btLoadParams.setObjectName("btLoadParams")
        self.btSaveParams = QtGui.QPushButton(self.ParamFilePanel)
        self.btSaveParams.setGeometry(QtCore.QRect(70, 20, 55, 25))
        self.btSaveParams.setObjectName("btSaveParams")
        self.TitleLabel = QtGui.QLabel(self.centralwidget)
        self.TitleLabel.setGeometry(QtCore.QRect(10, 0, 321, 31))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.TitleLabel.setFont(font)
        self.TitleLabel.setObjectName("TitleLabel")
        self.SamplePanel = QtGui.QGroupBox(self.centralwidget)
        self.SamplePanel.setGeometry(QtCore.QRect(10, 50, 530, 160))
        self.SamplePanel.setFlat(False)
        self.SamplePanel.setCheckable(False)
        self.SamplePanel.setObjectName("SamplePanel")
        self.txt14 = QtGui.QLineEdit(self.SamplePanel)
        self.txt14.setGeometry(QtCore.QRect(310, 130, 60, 20))
        self.txt14.setText("")
        self.txt14.setObjectName("txt14")
        self.txt13 = QtGui.QLineEdit(self.SamplePanel)
        self.txt13.setGeometry(QtCore.QRect(150, 130, 60, 20))
        self.txt13.setObjectName("txt13")
        self.label15 = QtGui.QLabel(self.SamplePanel)
        self.label15.setGeometry(QtCore.QRect(0, 130, 68, 17))
        self.label15.setObjectName("label15")
        self.txt2 = QtGui.QLineEdit(self.SamplePanel)
        self.txt2.setGeometry(QtCore.QRect(260, 30, 60, 20))
        self.txt2.setObjectName("txt2")
        self.label7 = QtGui.QLabel(self.SamplePanel)
        self.label7.setGeometry(QtCore.QRect(190, 50, 65, 20))
        self.label7.setObjectName("label7")
        self.txt11 = QtGui.QLineEdit(self.SamplePanel)
        self.txt11.setGeometry(QtCore.QRect(260, 100, 60, 20))
        self.txt11.setObjectName("txt11")
        self.txt15 = QtGui.QLineEdit(self.SamplePanel)
        self.txt15.setGeometry(QtCore.QRect(460, 130, 60, 20))
        self.txt15.setObjectName("txt15")
        self.txt5 = QtGui.QLineEdit(self.SamplePanel)
        self.txt5.setGeometry(QtCore.QRect(260, 50, 60, 20))
        self.txt5.setObjectName("txt5")
        self.txt6 = QtGui.QLineEdit(self.SamplePanel)
        self.txt6.setGeometry(QtCore.QRect(410, 50, 60, 20))
        self.txt6.setObjectName("txt6")
        self.label4 = QtGui.QLabel(self.SamplePanel)
        self.label4.setGeometry(QtCore.QRect(190, 30, 65, 20))
        self.label4.setObjectName("label4")
        self.label6 = QtGui.QLabel(self.SamplePanel)
        self.label6.setGeometry(QtCore.QRect(30, 50, 65, 20))
        self.label6.setObjectName("label6")
        self.label14 = QtGui.QLabel(self.SamplePanel)
        self.label14.setGeometry(QtCore.QRect(340, 100, 65, 20))
        self.label14.setObjectName("label14")
        self.label18 = QtGui.QLabel(self.SamplePanel)
        self.label18.setGeometry(QtCore.QRect(380, 130, 31, 17))
        self.label18.setObjectName("label18")
        self.txt4 = QtGui.QLineEdit(self.SamplePanel)
        self.txt4.setGeometry(QtCore.QRect(100, 50, 60, 20))
        self.txt4.setObjectName("txt4")
        self.txt8 = QtGui.QLineEdit(self.SamplePanel)
        self.txt8.setGeometry(QtCore.QRect(260, 80, 60, 20))
        self.txt8.setObjectName("txt8")
        self.label8 = QtGui.QLabel(self.SamplePanel)
        self.label8.setGeometry(QtCore.QRect(340, 50, 65, 20))
        self.label8.setObjectName("label8")
        self.chRotateAxis3rd = QtGui.QComboBox(self.SamplePanel)
        self.chRotateAxis3rd.setGeometry(QtCore.QRect(410, 125, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.chRotateAxis3rd.setFont(font)
        self.chRotateAxis3rd.setEditable(False)
        self.chRotateAxis3rd.setObjectName("chRotateAxis3rd")
        self.chRotateAxis3rd.addItem("")
        self.chRotateAxis3rd.setItemText(0, "")
        self.chRotateAxis3rd.addItem("")
        self.chRotateAxis3rd.addItem("")
        self.chRotateAxis3rd.addItem("")
        self.label17 = QtGui.QLabel(self.SamplePanel)
        self.label17.setGeometry(QtCore.QRect(230, 130, 31, 17))
        self.label17.setObjectName("label17")
        self.txt1 = QtGui.QLineEdit(self.SamplePanel)
        self.txt1.setGeometry(QtCore.QRect(100, 30, 60, 20))
        self.txt1.setObjectName("txt1")
        self.txt9 = QtGui.QLineEdit(self.SamplePanel)
        self.txt9.setGeometry(QtCore.QRect(410, 80, 60, 20))
        self.txt9.setObjectName("txt9")
        self.txt12 = QtGui.QLineEdit(self.SamplePanel)
        self.txt12.setGeometry(QtCore.QRect(410, 100, 60, 20))
        self.txt12.setObjectName("txt12")
        self.label11 = QtGui.QLabel(self.SamplePanel)
        self.label11.setGeometry(QtCore.QRect(340, 80, 65, 20))
        self.label11.setObjectName("label11")
        self.label10 = QtGui.QLabel(self.SamplePanel)
        self.label10.setGeometry(QtCore.QRect(190, 80, 65, 20))
        self.label10.setObjectName("label10")
        self.chRotateAxis2nd = QtGui.QComboBox(self.SamplePanel)
        self.chRotateAxis2nd.setGeometry(QtCore.QRect(260, 125, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.chRotateAxis2nd.setFont(font)
        self.chRotateAxis2nd.setEditable(False)
        self.chRotateAxis2nd.setObjectName("chRotateAxis2nd")
        self.chRotateAxis2nd.addItem("")
        self.chRotateAxis2nd.setItemText(0, "")
        self.chRotateAxis2nd.addItem("")
        self.chRotateAxis2nd.addItem("")
        self.chRotateAxis2nd.addItem("")
        self.label13 = QtGui.QLabel(self.SamplePanel)
        self.label13.setGeometry(QtCore.QRect(190, 100, 65, 20))
        self.label13.setObjectName("label13")
        self.chRotateAxis1st = QtGui.QComboBox(self.SamplePanel)
        self.chRotateAxis1st.setGeometry(QtCore.QRect(100, 125, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.chRotateAxis1st.setFont(font)
        self.chRotateAxis1st.setEditable(False)
        self.chRotateAxis1st.setObjectName("chRotateAxis1st")
        self.chRotateAxis1st.addItem("")
        self.chRotateAxis1st.setItemText(0, "")
        self.chRotateAxis1st.addItem("")
        self.chRotateAxis1st.addItem("")
        self.chRotateAxis1st.addItem("")
        self.label3 = QtGui.QLabel(self.SamplePanel)
        self.label3.setGeometry(QtCore.QRect(30, 30, 65, 20))
        self.label3.setObjectName("label3")
        self.txt3 = QtGui.QLineEdit(self.SamplePanel)
        self.txt3.setGeometry(QtCore.QRect(410, 30, 60, 20))
        self.txt3.setObjectName("txt3")
        self.label16 = QtGui.QLabel(self.SamplePanel)
        self.label16.setGeometry(QtCore.QRect(70, 130, 31, 17))
        self.label16.setObjectName("label16")
        self.txt7 = QtGui.QLineEdit(self.SamplePanel)
        self.txt7.setGeometry(QtCore.QRect(100, 80, 60, 20))
        self.txt7.setObjectName("txt7")
        self.label5 = QtGui.QLabel(self.SamplePanel)
        self.label5.setGeometry(QtCore.QRect(340, 30, 65, 20))
        self.label5.setObjectName("label5")
        self.txt10 = QtGui.QLineEdit(self.SamplePanel)
        self.txt10.setGeometry(QtCore.QRect(100, 100, 60, 20))
        self.txt10.setObjectName("txt10")
        self.label9 = QtGui.QLabel(self.SamplePanel)
        self.label9.setGeometry(QtCore.QRect(30, 80, 65, 20))
        self.label9.setObjectName("label9")
        self.label12 = QtGui.QLabel(self.SamplePanel)
        self.label12.setGeometry(QtCore.QRect(30, 100, 65, 20))
        self.label12.setObjectName("label12")
        self.ProjectionPanel = QtGui.QGroupBox(self.centralwidget)
        self.ProjectionPanel.setGeometry(QtCore.QRect(10, 210, 530, 135))
        self.ProjectionPanel.setObjectName("ProjectionPanel")
        self.ptxt1 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt1.setGeometry(QtCore.QRect(40, 40, 55, 20))
        self.ptxt1.setObjectName("ptxt1")
        self.label25 = QtGui.QLabel(self.ProjectionPanel)
        self.label25.setGeometry(QtCore.QRect(10, 40, 31, 17))
        self.label25.setObjectName("label25")
        self.ptxt2 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt2.setGeometry(QtCore.QRect(100, 40, 55, 20))
        self.ptxt2.setObjectName("ptxt2")
        self.ptxt3 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt3.setGeometry(QtCore.QRect(160, 40, 55, 20))
        self.ptxt3.setObjectName("ptxt3")
        self.ptxt4 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt4.setGeometry(QtCore.QRect(220, 40, 55, 20))
        self.ptxt4.setObjectName("ptxt4")
        self.ptxt9 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt9.setGeometry(QtCore.QRect(220, 60, 55, 20))
        self.ptxt9.setObjectName("ptxt9")
        self.label26 = QtGui.QLabel(self.ProjectionPanel)
        self.label26.setGeometry(QtCore.QRect(10, 60, 31, 17))
        self.label26.setObjectName("label26")
        self.ptxt8 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt8.setGeometry(QtCore.QRect(160, 60, 55, 20))
        self.ptxt8.setObjectName("ptxt8")
        self.ptxt6 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt6.setGeometry(QtCore.QRect(40, 60, 55, 20))
        self.ptxt6.setObjectName("ptxt6")
        self.ptxt7 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt7.setGeometry(QtCore.QRect(100, 60, 55, 20))
        self.ptxt7.setObjectName("ptxt7")
        self.label27 = QtGui.QLabel(self.ProjectionPanel)
        self.label27.setGeometry(QtCore.QRect(10, 80, 31, 17))
        self.label27.setObjectName("label27")
        self.label28 = QtGui.QLabel(self.ProjectionPanel)
        self.label28.setGeometry(QtCore.QRect(10, 100, 31, 17))
        self.label28.setObjectName("label28")
        self.ptxt5 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt5.setGeometry(QtCore.QRect(290, 40, 81, 20))
        self.ptxt5.setObjectName("ptxt5")
        self.ptxt10 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt10.setGeometry(QtCore.QRect(290, 60, 81, 20))
        self.ptxt10.setObjectName("ptxt10")
        self.label19 = QtGui.QLabel(self.ProjectionPanel)
        self.label19.setGeometry(QtCore.QRect(40, 20, 55, 20))
        self.label19.setAlignment(QtCore.Qt.AlignCenter)
        self.label19.setObjectName("label19")
        self.label20 = QtGui.QLabel(self.ProjectionPanel)
        self.label20.setGeometry(QtCore.QRect(100, 20, 55, 20))
        self.label20.setAlignment(QtCore.Qt.AlignCenter)
        self.label20.setObjectName("label20")
        self.label21 = QtGui.QLabel(self.ProjectionPanel)
        self.label21.setGeometry(QtCore.QRect(160, 20, 55, 20))
        self.label21.setAlignment(QtCore.Qt.AlignCenter)
        self.label21.setObjectName("label21")
        self.label23 = QtGui.QLabel(self.ProjectionPanel)
        self.label23.setGeometry(QtCore.QRect(220, 20, 55, 20))
        self.label23.setAlignment(QtCore.Qt.AlignCenter)
        self.label23.setObjectName("label23")
        self.label24 = QtGui.QLabel(self.ProjectionPanel)
        self.label24.setGeometry(QtCore.QRect(290, 20, 81, 20))
        self.label24.setAlignment(QtCore.Qt.AlignCenter)
        self.label24.setObjectName("label24")
        self.ptxt16 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt16.setGeometry(QtCore.QRect(40, 100, 55, 20))
        self.ptxt16.setObjectName("ptxt16")
        self.ptxt18 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt18.setGeometry(QtCore.QRect(160, 100, 55, 20))
        self.ptxt18.setObjectName("ptxt18")
        self.ptxt17 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt17.setGeometry(QtCore.QRect(100, 100, 55, 20))
        self.ptxt17.setObjectName("ptxt17")
        self.ptxt14 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt14.setGeometry(QtCore.QRect(220, 80, 55, 20))
        self.ptxt14.setObjectName("ptxt14")
        self.ptxt15 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt15.setGeometry(QtCore.QRect(290, 80, 81, 20))
        self.ptxt15.setObjectName("ptxt15")
        self.ptxt13 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt13.setGeometry(QtCore.QRect(160, 80, 55, 20))
        self.ptxt13.setObjectName("ptxt13")
        self.ptxt11 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt11.setGeometry(QtCore.QRect(40, 80, 55, 20))
        self.ptxt11.setObjectName("ptxt11")
        self.ptxt19 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt19.setGeometry(QtCore.QRect(220, 100, 55, 20))
        self.ptxt19.setObjectName("ptxt19")
        self.ptxt12 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt12.setGeometry(QtCore.QRect(100, 80, 55, 20))
        self.ptxt12.setObjectName("ptxt12")
        self.ptxt20 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt20.setGeometry(QtCore.QRect(290, 100, 81, 20))
        self.ptxt20.setObjectName("ptxt20")
        self.btClr = QtGui.QPushButton(self.ProjectionPanel)
        self.btClr.setGeometry(QtCore.QRect(460, 40, 60, 27))
        self.btClr.setObjectName("btClr")
        self.ptxt21 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt21.setGeometry(QtCore.QRect(380, 40, 61, 20))
        self.ptxt21.setObjectName("ptxt21")
        self.ptxt22 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt22.setGeometry(QtCore.QRect(380, 60, 61, 20))
        self.ptxt22.setObjectName("ptxt22")
        self.ptxt23 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt23.setGeometry(QtCore.QRect(380, 80, 61, 20))
        self.ptxt23.setObjectName("ptxt23")
        self.ptxt24 = QtGui.QLineEdit(self.ProjectionPanel)
        self.ptxt24.setGeometry(QtCore.QRect(380, 100, 61, 20))
        self.ptxt24.setObjectName("ptxt24")
        self.label24_2 = QtGui.QLabel(self.ProjectionPanel)
        self.label24_2.setGeometry(QtCore.QRect(380, 20, 61, 20))
        self.label24_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label24_2.setObjectName("label24_2")
        self.CondPanel = QtGui.QGroupBox(self.centralwidget)
        self.CondPanel.setGeometry(QtCore.QRect(10, 340, 530, 130))
        self.CondPanel.setObjectName("CondPanel")
        self.label = QtGui.QLabel(self.CondPanel)
        self.label.setGeometry(QtCore.QRect(0, 20, 71, 17))
        self.label.setObjectName("label")
        self.txEi = QtGui.QLineEdit(self.CondPanel)
        self.txEi.setGeometry(QtCore.QRect(70, 20, 71, 21))
        self.txEi.setObjectName("txEi")
        self.txminhw = QtGui.QLineEdit(self.CondPanel)
        self.txminhw.setGeometry(QtCore.QRect(170, 40, 71, 21))
        self.txminhw.setObjectName("txminhw")
        self.txmaxhw = QtGui.QLineEdit(self.CondPanel)
        self.txmaxhw.setGeometry(QtCore.QRect(260, 40, 71, 21))
        self.txmaxhw.setObjectName("txmaxhw")
        self.txdeltahw = QtGui.QLineEdit(self.CondPanel)
        self.txdeltahw.setGeometry(QtCore.QRect(430, 40, 71, 21))
        self.txdeltahw.setObjectName("txdeltahw")
        self.txminphi = QtGui.QLineEdit(self.CondPanel)
        self.txminphi.setGeometry(QtCore.QRect(170, 70, 71, 21))
        self.txminphi.setObjectName("txminphi")
        self.txmaxphi = QtGui.QLineEdit(self.CondPanel)
        self.txmaxphi.setGeometry(QtCore.QRect(260, 70, 71, 21))
        self.txmaxphi.setObjectName("txmaxphi")
        self.txdeltaphi = QtGui.QLineEdit(self.CondPanel)
        self.txdeltaphi.setGeometry(QtCore.QRect(430, 70, 71, 21))
        self.txdeltaphi.setObjectName("txdeltaphi")
        self.txrunno = QtGui.QLineEdit(self.CondPanel)
        self.txrunno.setGeometry(QtCore.QRect(340, 100, 81, 21))
        self.txrunno.setObjectName("txrunno")
        self.label_2 = QtGui.QLabel(self.CondPanel)
        self.label_2.setGeometry(QtCore.QRect(10, 40, 151, 21))
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.label_3 = QtGui.QLabel(self.CondPanel)
        self.label_3.setGeometry(QtCore.QRect(10, 70, 151, 21))
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.label_4 = QtGui.QLabel(self.CondPanel)
        self.label_4.setGeometry(QtCore.QRect(240, 40, 21, 17))
        self.label_4.setObjectName("label_4")
        self.label_5 = QtGui.QLabel(self.CondPanel)
        self.label_5.setGeometry(QtCore.QRect(240, 70, 21, 17))
        self.label_5.setObjectName("label_5")
        self.label_6 = QtGui.QLabel(self.CondPanel)
        self.label_6.setGeometry(QtCore.QRect(330, 40, 91, 21))
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.label_7 = QtGui.QLabel(self.CondPanel)
        self.label_7.setGeometry(QtCore.QRect(330, 70, 91, 21))
        self.label_7.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_7.setObjectName("label_7")
        self.label_8 = QtGui.QLabel(self.CondPanel)
        self.label_8.setGeometry(QtCore.QRect(10, 100, 321, 21))
        self.label_8.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_8.setObjectName("label_8")
        self.RangePanel = QtGui.QGroupBox(self.centralwidget)
        self.RangePanel.setGeometry(QtCore.QRect(10, 470, 530, 130))
        self.RangePanel.setObjectName("RangePanel")
        self.dtxt1 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt1.setGeometry(QtCore.QRect(60, 40, 60, 20))
        self.dtxt1.setObjectName("dtxt1")
        self.dtxt2 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt2.setGeometry(QtCore.QRect(140, 40, 60, 20))
        self.dtxt2.setObjectName("dtxt2")
        self.dtxt3 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt3.setGeometry(QtCore.QRect(240, 40, 60, 20))
        self.dtxt3.setObjectName("dtxt3")
        self.dtxt4 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt4.setGeometry(QtCore.QRect(60, 60, 60, 20))
        self.dtxt4.setObjectName("dtxt4")
        self.dtxt5 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt5.setGeometry(QtCore.QRect(140, 60, 60, 20))
        self.dtxt5.setObjectName("dtxt5")
        self.dtxt6 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt6.setGeometry(QtCore.QRect(240, 60, 60, 20))
        self.dtxt6.setObjectName("dtxt6")
        self.dtxt7 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt7.setGeometry(QtCore.QRect(60, 80, 60, 20))
        self.dtxt7.setObjectName("dtxt7")
        self.dtxt8 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt8.setGeometry(QtCore.QRect(140, 80, 60, 20))
        self.dtxt8.setObjectName("dtxt8")
        self.dtxt9 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt9.setGeometry(QtCore.QRect(240, 80, 60, 20))
        self.dtxt9.setObjectName("dtxt9")
        self.dtxt10 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt10.setGeometry(QtCore.QRect(60, 100, 60, 20))
        self.dtxt10.setObjectName("dtxt10")
        self.dtxt11 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt11.setGeometry(QtCore.QRect(140, 100, 60, 20))
        self.dtxt11.setObjectName("dtxt11")
        self.dtxt12 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt12.setGeometry(QtCore.QRect(240, 100, 60, 20))
        self.dtxt12.setObjectName("dtxt12")
        self.label_9 = QtGui.QLabel(self.RangePanel)
        self.label_9.setGeometry(QtCore.QRect(10, 40, 41, 17))
        self.label_9.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_9.setObjectName("label_9")
        self.label_10 = QtGui.QLabel(self.RangePanel)
        self.label_10.setGeometry(QtCore.QRect(10, 60, 41, 17))
        self.label_10.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_10.setObjectName("label_10")
        self.label_11 = QtGui.QLabel(self.RangePanel)
        self.label_11.setGeometry(QtCore.QRect(10, 80, 41, 17))
        self.label_11.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_11.setObjectName("label_11")
        self.label_12 = QtGui.QLabel(self.RangePanel)
        self.label_12.setGeometry(QtCore.QRect(10, 100, 41, 17))
        self.label_12.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_12.setObjectName("label_12")
        self.label_13 = QtGui.QLabel(self.RangePanel)
        self.label_13.setGeometry(QtCore.QRect(110, 20, 51, 17))
        self.label_13.setAlignment(QtCore.Qt.AlignCenter)
        self.label_13.setObjectName("label_13")
        self.label_14 = QtGui.QLabel(self.RangePanel)
        self.label_14.setGeometry(QtCore.QRect(120, 40, 21, 20))
        self.label_14.setAlignment(QtCore.Qt.AlignCenter)
        self.label_14.setObjectName("label_14")
        self.label_15 = QtGui.QLabel(self.RangePanel)
        self.label_15.setGeometry(QtCore.QRect(120, 60, 21, 20))
        self.label_15.setAlignment(QtCore.Qt.AlignCenter)
        self.label_15.setObjectName("label_15")
        self.label_16 = QtGui.QLabel(self.RangePanel)
        self.label_16.setGeometry(QtCore.QRect(120, 80, 21, 20))
        self.label_16.setAlignment(QtCore.Qt.AlignCenter)
        self.label_16.setObjectName("label_16")
        self.label_17 = QtGui.QLabel(self.RangePanel)
        self.label_17.setGeometry(QtCore.QRect(120, 100, 21, 20))
        self.label_17.setAlignment(QtCore.Qt.AlignCenter)
        self.label_17.setObjectName("label_17")
        self.label_18 = QtGui.QLabel(self.RangePanel)
        self.label_18.setGeometry(QtCore.QRect(250, 20, 51, 17))
        self.label_18.setAlignment(QtCore.Qt.AlignCenter)
        self.label_18.setObjectName("label_18")
        self.VirtualD4MatPanel = QtGui.QGroupBox(self.centralwidget)
        self.VirtualD4MatPanel.setGeometry(QtCore.QRect(350, 490, 171, 101))
        self.VirtualD4MatPanel.setObjectName("VirtualD4MatPanel")
        self.btFillRange = QtGui.QPushButton(self.VirtualD4MatPanel)
        self.btFillRange.setGeometry(QtCore.QRect(10, 30, 131, 27))
        self.btFillRange.setObjectName("btFillRange")
        self.btMakeVirtualMatrix = QtGui.QPushButton(self.VirtualD4MatPanel)
        self.btMakeVirtualMatrix.setGeometry(QtCore.QRect(10, 70, 151, 27))
        self.btMakeVirtualMatrix.setObjectName("btMakeVirtualMatrix")
        self.NewD4MatPanel = QtGui.QGroupBox(self.centralwidget)
        self.NewD4MatPanel.setGeometry(QtCore.QRect(10, 600, 371, 61))
        self.NewD4MatPanel.setObjectName("NewD4MatPanel")
        self.btEstimateD4MatSize = QtGui.QPushButton(self.NewD4MatPanel)
        self.btEstimateD4MatSize.setGeometry(QtCore.QRect(20, 25, 121, 27))
        self.btEstimateD4MatSize.setObjectName("btEstimateD4MatSize")
        self.btMakeNewD4Mat = QtGui.QPushButton(self.NewD4MatPanel)
        self.btMakeNewD4Mat.setGeometry(QtCore.QRect(200, 22, 151, 36))
        self.btMakeNewD4Mat.setObjectName("btMakeNewD4Mat")
        self.btClose = QtGui.QPushButton(self.centralwidget)
        self.btClose.setGeometry(QtCore.QRect(438, 626, 71, 31))
        self.btClose.setObjectName("btClose")
        D4matSlicerQtSub.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(D4matSlicerQtSub)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 550, 28))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        D4matSlicerQtSub.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(D4matSlicerQtSub)
        self.statusbar.setObjectName("statusbar")
        D4matSlicerQtSub.setStatusBar(self.statusbar)
        self.actionLoad_XtalParams = QtGui.QAction(D4matSlicerQtSub)
        self.actionLoad_XtalParams.setObjectName("actionLoad_XtalParams")
        self.actionSave_XtalParams = QtGui.QAction(D4matSlicerQtSub)
        self.actionSave_XtalParams.setObjectName("actionSave_XtalParams")
        self.actionExit = QtGui.QAction(D4matSlicerQtSub)
        self.actionExit.setObjectName("actionExit")
        self.menuFile.addAction(self.actionLoad_XtalParams)
        self.menuFile.addAction(self.actionSave_XtalParams)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menubar.addAction(self.menuFile.menuAction())

        self.retranslateUi(D4matSlicerQtSub)
        QtCore.QMetaObject.connectSlotsByName(D4matSlicerQtSub)
        D4matSlicerQtSub.setTabOrder(self.btLoadParams, self.btSaveParams)
        D4matSlicerQtSub.setTabOrder(self.btSaveParams, self.txt1)
        D4matSlicerQtSub.setTabOrder(self.txt1, self.txt2)
        D4matSlicerQtSub.setTabOrder(self.txt2, self.txt3)
        D4matSlicerQtSub.setTabOrder(self.txt3, self.txt4)
        D4matSlicerQtSub.setTabOrder(self.txt4, self.txt5)
        D4matSlicerQtSub.setTabOrder(self.txt5, self.txt6)
        D4matSlicerQtSub.setTabOrder(self.txt6, self.txt7)
        D4matSlicerQtSub.setTabOrder(self.txt7, self.txt8)
        D4matSlicerQtSub.setTabOrder(self.txt8, self.txt9)
        D4matSlicerQtSub.setTabOrder(self.txt9, self.txt10)
        D4matSlicerQtSub.setTabOrder(self.txt10, self.txt11)
        D4matSlicerQtSub.setTabOrder(self.txt11, self.txt12)
        D4matSlicerQtSub.setTabOrder(self.txt12, self.chRotateAxis1st)
        D4matSlicerQtSub.setTabOrder(self.chRotateAxis1st, self.txt13)
        D4matSlicerQtSub.setTabOrder(self.txt13, self.chRotateAxis2nd)
        D4matSlicerQtSub.setTabOrder(self.chRotateAxis2nd, self.txt14)
        D4matSlicerQtSub.setTabOrder(self.txt14, self.chRotateAxis3rd)
        D4matSlicerQtSub.setTabOrder(self.chRotateAxis3rd, self.txt15)
        D4matSlicerQtSub.setTabOrder(self.txt15, self.ptxt1)
        D4matSlicerQtSub.setTabOrder(self.ptxt1, self.ptxt2)
        D4matSlicerQtSub.setTabOrder(self.ptxt2, self.ptxt3)
        D4matSlicerQtSub.setTabOrder(self.ptxt3, self.ptxt4)
        D4matSlicerQtSub.setTabOrder(self.ptxt4, self.ptxt21)
        D4matSlicerQtSub.setTabOrder(self.ptxt21, self.ptxt5)
        D4matSlicerQtSub.setTabOrder(self.ptxt5, self.ptxt6)
        D4matSlicerQtSub.setTabOrder(self.ptxt6, self.ptxt7)
        D4matSlicerQtSub.setTabOrder(self.ptxt7, self.ptxt8)
        D4matSlicerQtSub.setTabOrder(self.ptxt8, self.ptxt22)
        D4matSlicerQtSub.setTabOrder(self.ptxt22, self.ptxt9)
        D4matSlicerQtSub.setTabOrder(self.ptxt9, self.ptxt10)
        D4matSlicerQtSub.setTabOrder(self.ptxt10, self.ptxt11)
        D4matSlicerQtSub.setTabOrder(self.ptxt11, self.ptxt12)
        D4matSlicerQtSub.setTabOrder(self.ptxt12, self.ptxt13)
        D4matSlicerQtSub.setTabOrder(self.ptxt13, self.ptxt23)
        D4matSlicerQtSub.setTabOrder(self.ptxt23, self.ptxt14)
        D4matSlicerQtSub.setTabOrder(self.ptxt14, self.ptxt15)
        D4matSlicerQtSub.setTabOrder(self.ptxt15, self.ptxt16)
        D4matSlicerQtSub.setTabOrder(self.ptxt16, self.ptxt17)
        D4matSlicerQtSub.setTabOrder(self.ptxt17, self.ptxt18)
        D4matSlicerQtSub.setTabOrder(self.ptxt18, self.ptxt19)
        D4matSlicerQtSub.setTabOrder(self.ptxt19, self.ptxt20)
        D4matSlicerQtSub.setTabOrder(self.ptxt20, self.ptxt24)
        D4matSlicerQtSub.setTabOrder(self.ptxt24, self.btClr)
        D4matSlicerQtSub.setTabOrder(self.btClr, self.txEi)
        D4matSlicerQtSub.setTabOrder(self.txEi, self.txminhw)
        D4matSlicerQtSub.setTabOrder(self.txminhw, self.txmaxhw)
        D4matSlicerQtSub.setTabOrder(self.txmaxhw, self.txdeltahw)
        D4matSlicerQtSub.setTabOrder(self.txdeltahw, self.txminphi)
        D4matSlicerQtSub.setTabOrder(self.txminphi, self.txmaxphi)
        D4matSlicerQtSub.setTabOrder(self.txmaxphi, self.txdeltaphi)
        D4matSlicerQtSub.setTabOrder(self.txdeltaphi, self.txrunno)
        D4matSlicerQtSub.setTabOrder(self.txrunno, self.dtxt1)
        D4matSlicerQtSub.setTabOrder(self.dtxt1, self.dtxt2)
        D4matSlicerQtSub.setTabOrder(self.dtxt2, self.dtxt3)
        D4matSlicerQtSub.setTabOrder(self.dtxt3, self.dtxt4)
        D4matSlicerQtSub.setTabOrder(self.dtxt4, self.dtxt5)
        D4matSlicerQtSub.setTabOrder(self.dtxt5, self.dtxt6)
        D4matSlicerQtSub.setTabOrder(self.dtxt6, self.dtxt7)
        D4matSlicerQtSub.setTabOrder(self.dtxt7, self.dtxt8)
        D4matSlicerQtSub.setTabOrder(self.dtxt8, self.dtxt9)
        D4matSlicerQtSub.setTabOrder(self.dtxt9, self.dtxt10)
        D4matSlicerQtSub.setTabOrder(self.dtxt10, self.dtxt11)
        D4matSlicerQtSub.setTabOrder(self.dtxt11, self.dtxt12)
        D4matSlicerQtSub.setTabOrder(self.dtxt12, self.btFillRange)
        D4matSlicerQtSub.setTabOrder(self.btFillRange, self.btMakeVirtualMatrix)
        D4matSlicerQtSub.setTabOrder(self.btMakeVirtualMatrix, self.btEstimateD4MatSize)
        D4matSlicerQtSub.setTabOrder(self.btEstimateD4MatSize, self.btMakeNewD4Mat)
        D4matSlicerQtSub.setTabOrder(self.btMakeNewD4Mat, self.btClose)

    def retranslateUi(self, D4matSlicerQtSub):
        D4matSlicerQtSub.setWindowTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.ParamFilePanel.setTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "Param File ...", None, QtGui.QApplication.UnicodeUTF8))
        self.btLoadParams.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Load", None, QtGui.QApplication.UnicodeUTF8))
        self.btSaveParams.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.TitleLabel.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Making Virtual or New D4Matrix", None, QtGui.QApplication.UnicodeUTF8))
        self.SamplePanel.setTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "Sample Information", None, QtGui.QApplication.UnicodeUTF8))
        self.label15.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Rotation", None, QtGui.QApplication.UnicodeUTF8))
        self.label7.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "beta:", None, QtGui.QApplication.UnicodeUTF8))
        self.label4.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "b (1/A):", None, QtGui.QApplication.UnicodeUTF8))
        self.label6.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "alpha:", None, QtGui.QApplication.UnicodeUTF8))
        self.label14.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Vl:", None, QtGui.QApplication.UnicodeUTF8))
        self.label18.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "3rd:", None, QtGui.QApplication.UnicodeUTF8))
        self.label8.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "gamma:", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis3rd.setItemText(1, QtGui.QApplication.translate("D4matSlicerQtSub", "Y", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis3rd.setItemText(2, QtGui.QApplication.translate("D4matSlicerQtSub", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis3rd.setItemText(3, QtGui.QApplication.translate("D4matSlicerQtSub", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label17.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "2nd:", None, QtGui.QApplication.UnicodeUTF8))
        self.label11.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Ul:", None, QtGui.QApplication.UnicodeUTF8))
        self.label10.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Uk:", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis2nd.setItemText(1, QtGui.QApplication.translate("D4matSlicerQtSub", "Y", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis2nd.setItemText(2, QtGui.QApplication.translate("D4matSlicerQtSub", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis2nd.setItemText(3, QtGui.QApplication.translate("D4matSlicerQtSub", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label13.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Vk:", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis1st.setItemText(1, QtGui.QApplication.translate("D4matSlicerQtSub", "Y", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis1st.setItemText(2, QtGui.QApplication.translate("D4matSlicerQtSub", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis1st.setItemText(3, QtGui.QApplication.translate("D4matSlicerQtSub", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label3.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "a (1/A):", None, QtGui.QApplication.UnicodeUTF8))
        self.label16.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "1st:", None, QtGui.QApplication.UnicodeUTF8))
        self.label5.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "a (1/A):", None, QtGui.QApplication.UnicodeUTF8))
        self.label9.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Uh:", None, QtGui.QApplication.UnicodeUTF8))
        self.label12.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Vh:", None, QtGui.QApplication.UnicodeUTF8))
        self.ProjectionPanel.setTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "Projection", None, QtGui.QApplication.UnicodeUTF8))
        self.label25.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "ax1:", None, QtGui.QApplication.UnicodeUTF8))
        self.label26.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "ax2:", None, QtGui.QApplication.UnicodeUTF8))
        self.label27.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "ax3:", None, QtGui.QApplication.UnicodeUTF8))
        self.label28.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "ax4:", None, QtGui.QApplication.UnicodeUTF8))
        self.label19.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "a*", None, QtGui.QApplication.UnicodeUTF8))
        self.label20.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "b*", None, QtGui.QApplication.UnicodeUTF8))
        self.label21.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "c*", None, QtGui.QApplication.UnicodeUTF8))
        self.label23.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Energy", None, QtGui.QApplication.UnicodeUTF8))
        self.label24.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Axis Label", None, QtGui.QApplication.UnicodeUTF8))
        self.btClr.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Clear", None, QtGui.QApplication.UnicodeUTF8))
        self.label24_2.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Unit", None, QtGui.QApplication.UnicodeUTF8))
        self.CondPanel.setTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "Measurement Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Ei (meV) :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Range (meV) :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Rotation Range (deg) :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "bin (meV) :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "step (deg) :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Detector\'s Structure : import from run No =", None, QtGui.QApplication.UnicodeUTF8))
        self.RangePanel.setTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "D4 Matrix", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "ax1 :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "ax2 :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "ax3 :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "ax4 :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_13.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_14.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_15.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_16.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_17.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_18.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Step", None, QtGui.QApplication.UnicodeUTF8))
        self.VirtualD4MatPanel.setTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "Virtual D4Mat", None, QtGui.QApplication.UnicodeUTF8))
        self.btFillRange.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Estimate Ranges", None, QtGui.QApplication.UnicodeUTF8))
        self.btMakeVirtualMatrix.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Make Virtual D4Mat", None, QtGui.QApplication.UnicodeUTF8))
        self.NewD4MatPanel.setTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "Make New D4Mat", None, QtGui.QApplication.UnicodeUTF8))
        self.btEstimateD4MatSize.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Estimate size", None, QtGui.QApplication.UnicodeUTF8))
        self.btMakeNewD4Mat.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Make New D4Mat", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Close", None, QtGui.QApplication.UnicodeUTF8))
        self.menuFile.setTitle(QtGui.QApplication.translate("D4matSlicerQtSub", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.actionLoad_XtalParams.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Load XtalParams ...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_XtalParams.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Save XtalParams ...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionExit.setText(QtGui.QApplication.translate("D4matSlicerQtSub", "Exit", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'D4matSlicerQ_MakeNewD4mat.ui'
#
# Created: Fri Apr  2 10:16:28 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_NewD4MatrixFrame(object):
    def setupUi(self, NewD4MatrixFrame):
        NewD4MatrixFrame.setObjectName("NewD4MatrixFrame")
        NewD4MatrixFrame.resize(470, 223)
        self.centralwidget = QtGui.QWidget(NewD4MatrixFrame)
        self.centralwidget.setObjectName("centralwidget")
        self.RangePanel = QtGui.QGroupBox(self.centralwidget)
        self.RangePanel.setGeometry(QtCore.QRect(0, 0, 451, 131))
        self.RangePanel.setObjectName("RangePanel")
        self.dtxt1 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt1.setGeometry(QtCore.QRect(50, 40, 60, 20))
        self.dtxt1.setObjectName("dtxt1")
        self.dtxt2 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt2.setGeometry(QtCore.QRect(130, 40, 60, 20))
        self.dtxt2.setObjectName("dtxt2")
        self.dtxt3 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt3.setGeometry(QtCore.QRect(210, 40, 60, 20))
        self.dtxt3.setObjectName("dtxt3")
        self.dtxt4 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt4.setGeometry(QtCore.QRect(50, 60, 60, 20))
        self.dtxt4.setObjectName("dtxt4")
        self.dtxt5 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt5.setGeometry(QtCore.QRect(130, 60, 60, 20))
        self.dtxt5.setObjectName("dtxt5")
        self.dtxt6 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt6.setGeometry(QtCore.QRect(210, 60, 60, 20))
        self.dtxt6.setObjectName("dtxt6")
        self.dtxt7 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt7.setGeometry(QtCore.QRect(50, 80, 60, 20))
        self.dtxt7.setObjectName("dtxt7")
        self.dtxt8 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt8.setGeometry(QtCore.QRect(130, 80, 60, 20))
        self.dtxt8.setObjectName("dtxt8")
        self.dtxt9 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt9.setGeometry(QtCore.QRect(210, 80, 60, 20))
        self.dtxt9.setObjectName("dtxt9")
        self.dtxt10 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt10.setGeometry(QtCore.QRect(50, 100, 60, 20))
        self.dtxt10.setObjectName("dtxt10")
        self.dtxt11 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt11.setGeometry(QtCore.QRect(130, 100, 60, 20))
        self.dtxt11.setObjectName("dtxt11")
        self.dtxt12 = QtGui.QLineEdit(self.RangePanel)
        self.dtxt12.setGeometry(QtCore.QRect(210, 100, 60, 20))
        self.dtxt12.setObjectName("dtxt12")
        self.label_9 = QtGui.QLabel(self.RangePanel)
        self.label_9.setGeometry(QtCore.QRect(0, 40, 41, 17))
        self.label_9.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_9.setObjectName("label_9")
        self.label_10 = QtGui.QLabel(self.RangePanel)
        self.label_10.setGeometry(QtCore.QRect(0, 60, 41, 17))
        self.label_10.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_10.setObjectName("label_10")
        self.label_11 = QtGui.QLabel(self.RangePanel)
        self.label_11.setGeometry(QtCore.QRect(0, 80, 41, 17))
        self.label_11.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_11.setObjectName("label_11")
        self.label_12 = QtGui.QLabel(self.RangePanel)
        self.label_12.setGeometry(QtCore.QRect(0, 100, 41, 17))
        self.label_12.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_12.setObjectName("label_12")
        self.label_13 = QtGui.QLabel(self.RangePanel)
        self.label_13.setGeometry(QtCore.QRect(100, 20, 51, 17))
        self.label_13.setAlignment(QtCore.Qt.AlignCenter)
        self.label_13.setObjectName("label_13")
        self.label_14 = QtGui.QLabel(self.RangePanel)
        self.label_14.setGeometry(QtCore.QRect(110, 40, 21, 20))
        self.label_14.setAlignment(QtCore.Qt.AlignCenter)
        self.label_14.setObjectName("label_14")
        self.label_15 = QtGui.QLabel(self.RangePanel)
        self.label_15.setGeometry(QtCore.QRect(110, 60, 21, 20))
        self.label_15.setAlignment(QtCore.Qt.AlignCenter)
        self.label_15.setObjectName("label_15")
        self.label_16 = QtGui.QLabel(self.RangePanel)
        self.label_16.setGeometry(QtCore.QRect(110, 80, 21, 20))
        self.label_16.setAlignment(QtCore.Qt.AlignCenter)
        self.label_16.setObjectName("label_16")
        self.label_17 = QtGui.QLabel(self.RangePanel)
        self.label_17.setGeometry(QtCore.QRect(110, 100, 21, 20))
        self.label_17.setAlignment(QtCore.Qt.AlignCenter)
        self.label_17.setObjectName("label_17")
        self.label_18 = QtGui.QLabel(self.RangePanel)
        self.label_18.setGeometry(QtCore.QRect(210, 20, 51, 17))
        self.label_18.setAlignment(QtCore.Qt.AlignCenter)
        self.label_18.setObjectName("label_18")
        self.v1title = QtGui.QLineEdit(self.RangePanel)
        self.v1title.setGeometry(QtCore.QRect(290, 40, 81, 21))
        self.v1title.setObjectName("v1title")
        self.v2title = QtGui.QLineEdit(self.RangePanel)
        self.v2title.setGeometry(QtCore.QRect(290, 60, 81, 21))
        self.v2title.setObjectName("v2title")
        self.v3title = QtGui.QLineEdit(self.RangePanel)
        self.v3title.setGeometry(QtCore.QRect(290, 80, 81, 21))
        self.v3title.setObjectName("v3title")
        self.v4title = QtGui.QLineEdit(self.RangePanel)
        self.v4title.setGeometry(QtCore.QRect(290, 100, 81, 21))
        self.v4title.setObjectName("v4title")
        self.label = QtGui.QLabel(self.RangePanel)
        self.label.setGeometry(QtCore.QRect(290, 20, 68, 17))
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.v1unit = QtGui.QLineEdit(self.RangePanel)
        self.v1unit.setGeometry(QtCore.QRect(380, 40, 61, 21))
        self.v1unit.setObjectName("v1unit")
        self.v2unit = QtGui.QLineEdit(self.RangePanel)
        self.v2unit.setGeometry(QtCore.QRect(380, 60, 61, 21))
        self.v2unit.setObjectName("v2unit")
        self.v3unit = QtGui.QLineEdit(self.RangePanel)
        self.v3unit.setGeometry(QtCore.QRect(380, 80, 61, 21))
        self.v3unit.setObjectName("v3unit")
        self.v4unit = QtGui.QLineEdit(self.RangePanel)
        self.v4unit.setGeometry(QtCore.QRect(380, 100, 61, 21))
        self.v4unit.setObjectName("v4unit")
        self.label_2 = QtGui.QLabel(self.RangePanel)
        self.label_2.setGeometry(QtCore.QRect(370, 20, 68, 17))
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.btLoadParams = QtGui.QPushButton(self.centralwidget)
        self.btLoadParams.setGeometry(QtCore.QRect(10, 140, 140, 30))
        self.btLoadParams.setObjectName("btLoadParams")
        self.btMakeNewMatrix = QtGui.QPushButton(self.centralwidget)
        self.btMakeNewMatrix.setGeometry(QtCore.QRect(170, 140, 140, 30))
        self.btMakeNewMatrix.setObjectName("btMakeNewMatrix")
        self.btClose = QtGui.QPushButton(self.centralwidget)
        self.btClose.setGeometry(QtCore.QRect(380, 140, 80, 30))
        self.btClose.setObjectName("btClose")
        NewD4MatrixFrame.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(NewD4MatrixFrame)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 470, 28))
        self.menubar.setObjectName("menubar")
        NewD4MatrixFrame.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(NewD4MatrixFrame)
        self.statusbar.setObjectName("statusbar")
        NewD4MatrixFrame.setStatusBar(self.statusbar)

        self.retranslateUi(NewD4MatrixFrame)
        QtCore.QMetaObject.connectSlotsByName(NewD4MatrixFrame)
        NewD4MatrixFrame.setTabOrder(self.dtxt1, self.dtxt2)
        NewD4MatrixFrame.setTabOrder(self.dtxt2, self.dtxt3)
        NewD4MatrixFrame.setTabOrder(self.dtxt3, self.v1title)
        NewD4MatrixFrame.setTabOrder(self.v1title, self.v1unit)
        NewD4MatrixFrame.setTabOrder(self.v1unit, self.dtxt4)
        NewD4MatrixFrame.setTabOrder(self.dtxt4, self.dtxt5)
        NewD4MatrixFrame.setTabOrder(self.dtxt5, self.dtxt6)
        NewD4MatrixFrame.setTabOrder(self.dtxt6, self.v2title)
        NewD4MatrixFrame.setTabOrder(self.v2title, self.v2unit)
        NewD4MatrixFrame.setTabOrder(self.v2unit, self.dtxt7)
        NewD4MatrixFrame.setTabOrder(self.dtxt7, self.dtxt8)
        NewD4MatrixFrame.setTabOrder(self.dtxt8, self.dtxt9)
        NewD4MatrixFrame.setTabOrder(self.dtxt9, self.v3title)
        NewD4MatrixFrame.setTabOrder(self.v3title, self.v3unit)
        NewD4MatrixFrame.setTabOrder(self.v3unit, self.dtxt10)
        NewD4MatrixFrame.setTabOrder(self.dtxt10, self.dtxt11)
        NewD4MatrixFrame.setTabOrder(self.dtxt11, self.dtxt12)
        NewD4MatrixFrame.setTabOrder(self.dtxt12, self.v4title)
        NewD4MatrixFrame.setTabOrder(self.v4title, self.v4unit)
        NewD4MatrixFrame.setTabOrder(self.v4unit, self.btLoadParams)
        NewD4MatrixFrame.setTabOrder(self.btLoadParams, self.btMakeNewMatrix)
        NewD4MatrixFrame.setTabOrder(self.btMakeNewMatrix, self.btClose)

    def retranslateUi(self, NewD4MatrixFrame):
        NewD4MatrixFrame.setWindowTitle(QtGui.QApplication.translate("NewD4MatrixFrame", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.RangePanel.setTitle(QtGui.QApplication.translate("NewD4MatrixFrame", "D4 Matrix", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "ax1 :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "ax2 :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "ax3 :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "ax4 :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_13.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_14.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_15.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_16.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_17.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_18.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "Step", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "Title", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "Unit", None, QtGui.QApplication.UnicodeUTF8))
        self.btLoadParams.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "Load param file", None, QtGui.QApplication.UnicodeUTF8))
        self.btMakeNewMatrix.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "Make New D4Mat", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("NewD4MatrixFrame", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'D4matSlicerQ_Rebin.ui'
#
# Created: Fri Apr  2 10:16:28 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_D4matSlicerQRebin(object):
    def setupUi(self, D4matSlicerQRebin):
        D4matSlicerQRebin.setObjectName("D4matSlicerQRebin")
        D4matSlicerQRebin.resize(510, 249)
        self.centralwidget = QtGui.QWidget(D4matSlicerQRebin)
        self.centralwidget.setObjectName("centralwidget")
        self.panel3 = QtGui.QGroupBox(self.centralwidget)
        self.panel3.setGeometry(QtCore.QRect(0, 0, 501, 171))
        self.panel3.setObjectName("panel3")
        self.label_2 = QtGui.QLabel(self.panel3)
        self.label_2.setGeometry(QtCore.QRect(100, 20, 60, 20))
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.label_3 = QtGui.QLabel(self.panel3)
        self.label_3.setGeometry(QtCore.QRect(230, 20, 60, 20))
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.label_4 = QtGui.QLabel(self.panel3)
        self.label_4.setGeometry(QtCore.QRect(400, 20, 60, 20))
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName("label_4")
        self.v1txt = QtGui.QLabel(self.panel3)
        self.v1txt.setGeometry(QtCore.QRect(10, 40, 30, 20))
        self.v1txt.setObjectName("v1txt")
        self.txt1 = QtGui.QLabel(self.panel3)
        self.txt1.setGeometry(QtCore.QRect(50, 40, 60, 20))
        self.txt1.setAlignment(QtCore.Qt.AlignCenter)
        self.txt1.setObjectName("txt1")
        self.label_6 = QtGui.QLabel(self.panel3)
        self.label_6.setGeometry(QtCore.QRect(110, 40, 30, 20))
        self.label_6.setAlignment(QtCore.Qt.AlignCenter)
        self.label_6.setObjectName("label_6")
        self.txt2 = QtGui.QLabel(self.panel3)
        self.txt2.setGeometry(QtCore.QRect(140, 40, 60, 20))
        self.txt2.setAlignment(QtCore.Qt.AlignCenter)
        self.txt2.setObjectName("txt2")
        self.txt3 = QtGui.QLabel(self.panel3)
        self.txt3.setGeometry(QtCore.QRect(230, 40, 60, 20))
        self.txt3.setAlignment(QtCore.Qt.AlignCenter)
        self.txt3.setObjectName("txt3")
        self.label_7 = QtGui.QLabel(self.panel3)
        self.label_7.setGeometry(QtCore.QRect(110, 70, 30, 20))
        self.label_7.setAlignment(QtCore.Qt.AlignCenter)
        self.label_7.setObjectName("label_7")
        self.txt5 = QtGui.QLabel(self.panel3)
        self.txt5.setGeometry(QtCore.QRect(140, 70, 60, 20))
        self.txt5.setAlignment(QtCore.Qt.AlignCenter)
        self.txt5.setObjectName("txt5")
        self.txt4 = QtGui.QLabel(self.panel3)
        self.txt4.setGeometry(QtCore.QRect(50, 70, 60, 20))
        self.txt4.setAlignment(QtCore.Qt.AlignCenter)
        self.txt4.setObjectName("txt4")
        self.v2txt = QtGui.QLabel(self.panel3)
        self.v2txt.setGeometry(QtCore.QRect(10, 70, 30, 20))
        self.v2txt.setObjectName("v2txt")
        self.txt6 = QtGui.QLabel(self.panel3)
        self.txt6.setGeometry(QtCore.QRect(230, 70, 60, 20))
        self.txt6.setAlignment(QtCore.Qt.AlignCenter)
        self.txt6.setObjectName("txt6")
        self.label_8 = QtGui.QLabel(self.panel3)
        self.label_8.setGeometry(QtCore.QRect(110, 100, 30, 20))
        self.label_8.setAlignment(QtCore.Qt.AlignCenter)
        self.label_8.setObjectName("label_8")
        self.txt8 = QtGui.QLabel(self.panel3)
        self.txt8.setGeometry(QtCore.QRect(140, 100, 60, 20))
        self.txt8.setAlignment(QtCore.Qt.AlignCenter)
        self.txt8.setObjectName("txt8")
        self.txt7 = QtGui.QLabel(self.panel3)
        self.txt7.setGeometry(QtCore.QRect(50, 100, 60, 20))
        self.txt7.setAlignment(QtCore.Qt.AlignCenter)
        self.txt7.setObjectName("txt7")
        self.v3txt = QtGui.QLabel(self.panel3)
        self.v3txt.setGeometry(QtCore.QRect(10, 100, 30, 20))
        self.v3txt.setObjectName("v3txt")
        self.txt9 = QtGui.QLabel(self.panel3)
        self.txt9.setGeometry(QtCore.QRect(230, 100, 60, 20))
        self.txt9.setAlignment(QtCore.Qt.AlignCenter)
        self.txt9.setObjectName("txt9")
        self.label_9 = QtGui.QLabel(self.panel3)
        self.label_9.setGeometry(QtCore.QRect(110, 130, 30, 20))
        self.label_9.setAlignment(QtCore.Qt.AlignCenter)
        self.label_9.setObjectName("label_9")
        self.txt11 = QtGui.QLabel(self.panel3)
        self.txt11.setGeometry(QtCore.QRect(140, 130, 60, 20))
        self.txt11.setAlignment(QtCore.Qt.AlignCenter)
        self.txt11.setObjectName("txt11")
        self.txt10 = QtGui.QLabel(self.panel3)
        self.txt10.setGeometry(QtCore.QRect(50, 130, 60, 20))
        self.txt10.setAlignment(QtCore.Qt.AlignCenter)
        self.txt10.setObjectName("txt10")
        self.v4txt = QtGui.QLabel(self.panel3)
        self.v4txt.setGeometry(QtCore.QRect(10, 130, 30, 20))
        self.v4txt.setObjectName("v4txt")
        self.txt12 = QtGui.QLabel(self.panel3)
        self.txt12.setGeometry(QtCore.QRect(230, 130, 60, 20))
        self.txt12.setAlignment(QtCore.Qt.AlignCenter)
        self.txt12.setObjectName("txt12")
        self.v1title = QtGui.QLineEdit(self.panel3)
        self.v1title.setGeometry(QtCore.QRect(380, 40, 120, 20))
        self.v1title.setObjectName("v1title")
        self.v2title = QtGui.QLineEdit(self.panel3)
        self.v2title.setGeometry(QtCore.QRect(380, 70, 120, 20))
        self.v2title.setObjectName("v2title")
        self.v3title = QtGui.QLineEdit(self.panel3)
        self.v3title.setGeometry(QtCore.QRect(380, 100, 120, 20))
        self.v3title.setObjectName("v3title")
        self.v4title = QtGui.QLineEdit(self.panel3)
        self.v4title.setGeometry(QtCore.QRect(380, 130, 120, 20))
        self.v4title.setObjectName("v4title")
        self.spn1StepRatio = QtGui.QSpinBox(self.panel3)
        self.spn1StepRatio.setGeometry(QtCore.QRect(300, 40, 61, 25))
        self.spn1StepRatio.setObjectName("spn1StepRatio")
        self.spn2StepRatio = QtGui.QSpinBox(self.panel3)
        self.spn2StepRatio.setGeometry(QtCore.QRect(300, 70, 61, 25))
        self.spn2StepRatio.setObjectName("spn2StepRatio")
        self.spn3StepRatio = QtGui.QSpinBox(self.panel3)
        self.spn3StepRatio.setGeometry(QtCore.QRect(300, 100, 61, 25))
        self.spn3StepRatio.setObjectName("spn3StepRatio")
        self.spn4StepRatio = QtGui.QSpinBox(self.panel3)
        self.spn4StepRatio.setGeometry(QtCore.QRect(300, 130, 61, 25))
        self.spn4StepRatio.setObjectName("spn4StepRatio")
        self.label = QtGui.QLabel(self.panel3)
        self.label.setGeometry(QtCore.QRect(300, 20, 51, 17))
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.label_5 = QtGui.QLabel(self.panel3)
        self.label_5.setGeometry(QtCore.QRect(290, 40, 10, 25))
        self.label_5.setObjectName("label_5")
        self.label_10 = QtGui.QLabel(self.panel3)
        self.label_10.setGeometry(QtCore.QRect(290, 70, 10, 25))
        self.label_10.setObjectName("label_10")
        self.label_11 = QtGui.QLabel(self.panel3)
        self.label_11.setGeometry(QtCore.QRect(290, 100, 10, 25))
        self.label_11.setObjectName("label_11")
        self.label_12 = QtGui.QLabel(self.panel3)
        self.label_12.setGeometry(QtCore.QRect(290, 130, 10, 25))
        self.label_12.setObjectName("label_12")
        self.btRebinMatrix = QtGui.QPushButton(self.centralwidget)
        self.btRebinMatrix.setGeometry(QtCore.QRect(170, 170, 140, 30))
        self.btRebinMatrix.setObjectName("btRebinMatrix")
        self.btClose = QtGui.QPushButton(self.centralwidget)
        self.btClose.setGeometry(QtCore.QRect(438, 170, 61, 27))
        self.btClose.setObjectName("btClose")
        D4matSlicerQRebin.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(D4matSlicerQRebin)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 510, 25))
        self.menubar.setObjectName("menubar")
        D4matSlicerQRebin.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(D4matSlicerQRebin)
        self.statusbar.setObjectName("statusbar")
        D4matSlicerQRebin.setStatusBar(self.statusbar)

        self.retranslateUi(D4matSlicerQRebin)
        QtCore.QMetaObject.connectSlotsByName(D4matSlicerQRebin)
        D4matSlicerQRebin.setTabOrder(self.spn1StepRatio, self.v1title)
        D4matSlicerQRebin.setTabOrder(self.v1title, self.spn2StepRatio)
        D4matSlicerQRebin.setTabOrder(self.spn2StepRatio, self.v2title)
        D4matSlicerQRebin.setTabOrder(self.v2title, self.spn3StepRatio)
        D4matSlicerQRebin.setTabOrder(self.spn3StepRatio, self.v3title)
        D4matSlicerQRebin.setTabOrder(self.v3title, self.spn4StepRatio)
        D4matSlicerQRebin.setTabOrder(self.spn4StepRatio, self.v4title)
        D4matSlicerQRebin.setTabOrder(self.v4title, self.btRebinMatrix)
        D4matSlicerQRebin.setTabOrder(self.btRebinMatrix, self.btClose)

    def retranslateUi(self, D4matSlicerQRebin):
        D4matSlicerQRebin.setWindowTitle(QtGui.QApplication.translate("D4matSlicerQRebin", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.panel3.setTitle(QtGui.QApplication.translate("D4matSlicerQRebin", "D4Matrix Info", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Step", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Title", None, QtGui.QApplication.UnicodeUTF8))
        self.v1txt.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Ax1:", None, QtGui.QApplication.UnicodeUTF8))
        self.txt1.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "-1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.txt2.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txt3.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.txt5.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txt4.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "-1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.v2txt.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Ax2:", None, QtGui.QApplication.UnicodeUTF8))
        self.txt6.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.txt8.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txt7.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "-1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.v3txt.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Ax3:", None, QtGui.QApplication.UnicodeUTF8))
        self.txt9.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.txt11.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txt10.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "-1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.v4txt.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Ax4:", None, QtGui.QApplication.UnicodeUTF8))
        self.txt12.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Ratio", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.btRebinMatrix.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Rebin D4Mat", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("D4matSlicerQRebin", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgSaveAsText.ui'
#
# Created: Fri Apr  2 10:16:28 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgSaveAsText(object):
    def setupUi(self, DgSaveAsText):
        DgSaveAsText.setObjectName("DgSaveAsText")
        DgSaveAsText.resize(400, 197)
        self.frame = QtGui.QFrame(DgSaveAsText)
        self.frame.setGeometry(QtCore.QRect(10, 10, 371, 121))
        self.frame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.ckIgnoreMask = QtGui.QCheckBox(self.frame)
        self.ckIgnoreMask.setGeometry(QtCore.QRect(10, 10, 181, 22))
        self.ckIgnoreMask.setObjectName("ckIgnoreMask")
        self.label = QtGui.QLabel(self.frame)
        self.label.setGeometry(QtCore.QRect(50, 50, 181, 17))
        self.label.setObjectName("label")
        self.chMaskValue = QtGui.QComboBox(self.frame)
        self.chMaskValue.setGeometry(QtCore.QRect(220, 45, 131, 27))
        self.chMaskValue.setObjectName("chMaskValue")
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.txMaskValue = QtGui.QLineEdit(self.frame)
        self.txMaskValue.setGeometry(QtCore.QRect(220, 80, 131, 27))
        self.txMaskValue.setObjectName("txMaskValue")
        self.btSave = QtGui.QPushButton(DgSaveAsText)
        self.btSave.setGeometry(QtCore.QRect(30, 150, 121, 27))
        self.btSave.setObjectName("btSave")
        self.btCancel = QtGui.QPushButton(DgSaveAsText)
        self.btCancel.setGeometry(QtCore.QRect(240, 150, 121, 27))
        self.btCancel.setObjectName("btCancel")

        self.retranslateUi(DgSaveAsText)
        QtCore.QMetaObject.connectSlotsByName(DgSaveAsText)
        DgSaveAsText.setTabOrder(self.ckIgnoreMask, self.chMaskValue)
        DgSaveAsText.setTabOrder(self.chMaskValue, self.txMaskValue)
        DgSaveAsText.setTabOrder(self.txMaskValue, self.btSave)
        DgSaveAsText.setTabOrder(self.btSave, self.btCancel)

    def retranslateUi(self, DgSaveAsText):
        DgSaveAsText.setWindowTitle(QtGui.QApplication.translate("DgSaveAsText", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.ckIgnoreMask.setText(QtGui.QApplication.translate("DgSaveAsText", "Ignore Masked Points", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgSaveAsText", "Replace MaskValue with", None, QtGui.QApplication.UnicodeUTF8))
        self.chMaskValue.setItemText(0, QtGui.QApplication.translate("DgSaveAsText", "Value Below", None, QtGui.QApplication.UnicodeUTF8))
        self.chMaskValue.setItemText(1, QtGui.QApplication.translate("DgSaveAsText", "0", None, QtGui.QApplication.UnicodeUTF8))
        self.chMaskValue.setItemText(2, QtGui.QApplication.translate("DgSaveAsText", "-1", None, QtGui.QApplication.UnicodeUTF8))
        self.chMaskValue.setItemText(3, QtGui.QApplication.translate("DgSaveAsText", "Original Value", None, QtGui.QApplication.UnicodeUTF8))
        self.btSave.setText(QtGui.QApplication.translate("DgSaveAsText", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.btCancel.setText(QtGui.QApplication.translate("DgSaveAsText", "Cancel", None, QtGui.QApplication.UnicodeUTF8))




#!/usr/bin/python

from math import *
import numpy as np
import Manyo as m
import MovingAverage

####    linear combination of gaussian    ####
def dist(x, n, a, c, w):
    sum=0.0
    for i in range(n):
        sum = sum + a[i]*exp(-1.0*((x-c[i])/w[i])**2)
    return sum

####    sign function    ####
def sign(r):
    if r > 0.0:
        s = 1.0
    elif r == 0.0:
        s = 0.0
    else:
        s = -1.0
    return s

####    initialize an ElementContainer    ####
def initElementContainer(xmin, xmax, nDiv):

    bin = m.MakeDoubleVector(nDiv+1)
    delta = (xmax - xmin)/nDiv
    for i in range(nDiv+1):
        bin[i] = xmin + delta*i

    xc = m.MakeDoubleVector(nDiv)
    for i in range(nDiv):
        xc[i] = (bin[i] + bin[i+1])/2.0

    nPeak=1
    a=m.MakeDoubleVector(nPeak)
    c=m.MakeDoubleVector(nPeak)
    w=m.MakeDoubleVector(nPeak)
    a[0]=100000.0
    c[0]=7.5
    w[0]=2.5
    y = m.MakeDoubleVector(nDiv)
    e = m.MakeDoubleVector(nDiv)
    for i in range(nDiv):
        p = dist(xc[i], nPeak, a, c, w)
        q = sign(np.random.rand(1)-0.5)*(p/10.0)*sqrt(-1.0*log(np.random.rand(1)))
        y[i] = p + q
        e[i] = p/10.0

    ec = m.ElementContainer()
    ec.AddToHeader("run number", 1)
    ec.AddToHeader("level",      1)
    ec.AddToHeader("Inst.",      "manyo")
    ec.Add("TOF",       bin, "sec." )
    ec.Add("Intensity", y,   "count")
    ec.Add("Error",     e,   "count")
    ec.SetKeys("TOF", "Intensity", "Error")

    return ec

def outputElementContainer(ec):
    bin = ec.Put(ec.PutXKey())
    y   = ec.Put(ec.PutYKey())
    e   = ec.Put(ec.PutEKey())

    print str("No.").rjust(4), str("----------- bin -----------").rjust(27), str("xc").rjust(10), str("Intensity").rjust(23), str("error").rjust(23)
    for i in range(ec.PutSize(ec.PutYKey())):
         print str(i).rjust(4), "[", str(bin[i]).rjust(10), ",", str(bin[i+1]).rjust(10), ")", str((bin[i]+bin[i+1])/2.0).rjust(10), str(y[i]).rjust(23), str(e[i]).rjust(23)

####    plot    ####
def plot(src, dest):
    srcBin  = src.Put(src.PutXKey())
    srcY    = src.Put(src.PutYKey())
    destBin = dest.Put(dest.PutXKey())
    destY   = dest.Put(dest.PutYKey())

    count=0
    g=m.GnuplotInterface()
    g.e("set xrange[0: 15]")
    g.e("set yrange[0: 150000]")
    g.e("plot '-' using 1:2 with lines linewidth 1 title'%d', '-' using 1:3 with lines linewidth 4" %count)
    while 1:
        for i in range(srcY.size()):
            #print str( (srcBin[i]+srcBin[i+1])/2.0 ) + " " + str( srcY[i] )+ " " + str( destY[i] )
            g.e( str( (srcBin[i]+srcBin[i+1])/2.0 ) + " " + str( srcY[i] )+ " " + str( destY[i] ) )
        g.e("e")
        c=raw_input("")
        if c != "":
            break


####    main routine    ####
xmin = 0.0
xmax = 15.0
nDiv = 1500
src = initElementContainer(xmin, xmax, nDiv)
outputElementContainer(src)

domain = MovingAverage.Domain()
domain.setSource(src)
domain.setRange(xmin, xmax)
print "[", str(domain.getLowerBound()).rjust(10), ",", str(domain.getUpperBound()).rjust(10), "]"
print "[", str(domain.getLowerBoundID()).rjust(10), ",", str(domain.getUpperBoundID()).rjust(10), "]"
print
print "type of the domain", domain.getType()
#domain.setType(Domain.OO)
#print "type of the domain", domain.getType()

param = MovingAverage.ParamSet()
param.add(MovingAverage.MovingAverage.WINDOW_WIDTH,         111)
param.add(MovingAverage.MovingAverage.WINDOW_UPPER,          55)
param.add(MovingAverage.MovingAverage.USE_STRICT_DEFINITION,  0)
param.dump()

method = MovingAverage.MovingAverage()
param = method.setDefaultParam(src)
method.setDefaultParam(src).dump()
print "check param: ", method.checkParam(src, domain, param)

if method.checkParam(src, domain, param) :
    method.toInnerForm(src, domain, param)
    method.fit()
    method.eval()
    result = m.ElementContainer(src.PutHeader())
    method.toElementContainer(src, result)
    #result.dump()
    #outputElementContainer(result)
    plot(src, result)

